cd "C:\Users\Yang Sun\Dropbox\TDF\Output"

*** Define programs
set more off 
cap prog drop _all
program define winsor

sum `1', d
replace `1'=r(p1) if `1'<r(p1) & `1'!=.
replace `1'=r(p99) if `1'>r(p99) &`1'!=. 
end
program define clean
sum `1',d
replace `1' = r(p50)-5*(r(p75)-r(p25)) if `1'<(r(p50)-5*(r(p75)-r(p25)))&`1'~=.
replace `1' = r(p50)+5*(r(p75)-r(p25)) if `1'>(r(p50)+5*(r(p75)-r(p25)))&`1'~=.
end
program define winsor5
sum `1', d
replace `1'=r(p5) if `1'<r(p5) & `1'!=.
replace `1'=r(p95) if `1'>r(p95) &`1'!=. 
end
program define trim
sum `1', d
replace `1'=. if `1'<r(p1) & `1'!=.
replace `1'=. if `1'>r(p99) &`1'!=. 
end


******************************************************************************
************************* MUTUAL FUNDS SHARE CLASS LEVEL QUARTERLY PANEL
******** Quarterly share class level returns, constructed from monthly returns
use "../Data/CRSP MFDB/mret_tna_201801_202212.dta", clear
gen ym=mofd(caldt)
format ym %tm
replace mtna=. if mtna==-99
** get rid of duplicate obs
collapse (mean)mtna mret mnav, by(crsp_fundno ym)
drop if mret==.

** compound quarterly returns
gen quarter=qofd(dofm(ym))
bys crsp_fundno quarter: egen count=count(mret)
keep if count==3
gen lnmret1=ln(1+mret)
by crsp_fundno quarter: egen sumlnmret1=sum(lnmret1)
gen qret=exp(sumlnmret1)-1

by crsp_fundno quarter: egen avgnav=mean(mnav)

*** keep quarter end
gen month=month(dofm(ym))
order crsp_fundno ym month quarter
keep if month==3 | month==6 | month==9 | month==12
duplicates report crsp_fundno quarter

keeporder crsp_fundno quarter qret avgnav mnav

sort crsp_fundno quarter
by crsp_fundno: gen Lmnav=mnav[_n-1] if quarter==quarter[_n-1]+1
save qret2022.dta, replace



***** Share class level characteristics. Key variables: expense ratio, inception month, size, institutional share class indicator

use "../Data/CRSP MFDB/fundq_2018q1_2022q4.dta", clear
sort crsp_fundno caldt
gen quarter=qofd(caldt)
format quarter %tq
drop summary_period2 caldt turn_ratio
duplicates drop
duplicates report crsp_fundno quarter
sort crsp_fundno quarter
order crsp_fundno quarter

** fund size
replace tna_latest=. if tna_latest<0

** fund inception month
by crsp_fundno: egen inception_month=min(mofd(first_offer_dt))
format inception_month %tm
drop first_offer_dt

** expense ratio
replace exp_ratio=. if exp_ratio==-99
replace exp_ratio=. if exp_ratio>.1 /*drop extrem outliers*/

** institutional indicator
gen ins0=(inst_fund=="Y")
bys crsp_fundno: egen ins=max(ins0)
drop ins0
drop inst_fund

** fill in mgmt_cd
sort crsp_fundno quarter
forvalues i=1/10 {
by crsp_fundno: replace mgmt_cd=mgmt_cd[_n+`i'] if mgmt_cd=="" & mgmt_cd[_n+`i']!=""
}
by crsp_fundno: replace mgmt_cd=mgmt_cd[_n-1] if mgmt_cd=="" & mgmt_cd[_n-1]!=""

codebook mgmt_cd /* missing for about 9% of obs */

** clean up fund family names and manually assign them to correct mgmt_cd -> saved as mgmt_cd1
gen mgmt_cd1=mgmt_cd
replace mgmt_name=upper(mgmt_name)
qui do "../Do files/Rename_mgmt_cd.do"

** use fund family name if mgmt_cd is missing -> saved as mgmt_cd2
gen mgmt_cd2=mgmt_cd1
replace mgmt_cd2=mgmt_name if mgmt_cd2=="" & mgmt_name!=""
codebook mgmt_cd1 /*missing for 4% of obs*/
codebook mgmt_cd2 /* missing for 0.1% of obs*/
joinby crsp_fundno quarter using qret2022, unm(b)
tab _m
keep if _m==1 | _m==3
drop _m
save fundq_2018_2022.dta, replace


*** Fund-quarterly level characteristics
* obtained from the largest share class of each fund
use fundq_2018_2022, clear
codebook crsp_portno
keep if crsp_portno!=.

* filling categories (CRSP objective and Lipper class) across share classes of same fund same quarter
sort crsp_portno quarter
by crsp_portno quarter: replace crsp_obj_cd=crsp_obj_cd[_n-1] if crsp_obj_cd=="" & crsp_obj_cd[_n-1]!="" & crsp_portno!=.
forvalues i=1/5{
by crsp_portno quarter: replace crsp_obj_cd=crsp_obj_cd[_n+`i'] if crsp_obj_cd=="" & crsp_obj_cd[_n+`i']!="" & crsp_portno!=.
}
by crsp_portno quarter: replace lipper_class=lipper_class[_n-1] if lipper_class=="" & lipper_class[_n-1]!="" & crsp_portno!=.
forvalues i=1/5{
by crsp_portno quarter: replace lipper_class=lipper_class[_n+`i'] if lipper_class=="" & lipper_class[_n+`i']!="" & crsp_portno!=.
}

* index fund and ETF indicator: fill through fund time series
gen index0=(index_fund_flag=="D")
bys crsp_portno: egen index=max(index0) if crsp_portno!=.
gen etf0=(et_flag=="F")
bys crsp_portno: egen etf=max(etf0) if crsp_portno!=.

* keep the largest share class of each fund
gen tmp=-tna_latest
sort crsp_portno quarter tmp
by crsp_portno quarter: gen fob=(_n==1)
keep if fob==1

keep crsp_portno quarter crsp_obj_cd lipper_class index etf mgmt_cd mgmt_cd1 mgmt_cd2 fund_name 

* fill in missing values for CRSP objective, Lipper class, and mgmt_cd longitudinally
sort crsp_portno quarter
forvalues i=1/10 {
by crsp_portno: replace crsp_obj_cd=crsp_obj_cd[_n+`i'] if crsp_obj_cd=="" & crsp_obj_cd[_n+`i']!=""
by crsp_portno: replace lipper_class=lipper_class[_n+`i'] if lipper_class=="" & lipper_class[_n+`i']!=""
by crsp_portno: replace mgmt_cd=mgmt_cd[_n+`i'] if mgmt_cd=="" & mgmt_cd[_n+`i']!=""
by crsp_portno: replace mgmt_cd1=mgmt_cd1[_n+`i'] if mgmt_cd1=="" & mgmt_cd1[_n+`i']!=""
by crsp_portno: replace mgmt_cd2=mgmt_cd2[_n+`i'] if mgmt_cd2=="" & mgmt_cd2[_n+`i']!=""
}
by crsp_portno: replace crsp_obj_cd=crsp_obj_cd[_n-1] if crsp_obj_cd=="" & crsp_obj_cd[_n-1]!=""
by crsp_portno: replace lipper_class=lipper_class[_n-1] if lipper_class=="" & lipper_class[_n-1]!=""
by crsp_portno: replace mgmt_cd=mgmt_cd[_n-1] if mgmt_cd=="" & mgmt_cd[_n-1]!=""
by crsp_portno: replace mgmt_cd1=mgmt_cd1[_n-1] if mgmt_cd1=="" & mgmt_cd1[_n-1]!=""
by crsp_portno: replace mgmt_cd2=mgmt_cd2[_n-1] if mgmt_cd2=="" & mgmt_cd2[_n-1]!=""

* Assign three broad categories, domestic equity, foreign equity, fixed income, and mixed
gen broadcat="dom_eq" if substr(crsp_obj_cd,1,2)=="ED"
tab crsp_obj_cd if broadcat=="dom_eq"

replace broadcat="for_eq" if substr(crsp_obj_cd,1,2)=="EF"
tab crsp_obj_cd if broadcat=="for_eq"

replace broadcat="fixed_inc" if substr(crsp_obj_cd,1,1)=="I"
tab crsp_obj_cd if broadcat=="fixed_inc"

replace broadcat="mixed" if substr(crsp_obj_cd,1,1)=="M"
tab crsp_obj_cd if broadcat=="mixed"
save fundqtrfixed22.dta, replace


***** use cusip as an identifier to be merged with holdings
use fundq_2018_2022, clear
codebook cusip8
sort crsp_fundno quarter
forvalues i=1/10{
by crsp_fundno: replace cusip8=cusip8[_n+`i'] if cusip8=="" & cusip8[_n+`i']!=""
}
by crsp_fundno: replace cusip8=cusip8[_n-1] if cusip8=="" & cusip8[_n-1]!=""
codebook cusip8
ren cusip8 cusip
drop if cusip==""
drop if crsp_portno==.

drop crsp_obj_cd lipper_class index

joinby crsp_portno quarter using fundqtrfixed22, unm(b)
keep if _m==1 | _m==3
drop _m

** fill Lipper classifications
sort crsp_fundno quarter
forvalues i=1/10{
by crsp_fundno: replace lipper_class=lipper_class[_n+`i'] if lipper_class=="" & lipper_class[_n+`i']!=""
}
by crsp_fundno: replace lipper_class=lipper_class[_n-1] if lipper_class=="" & lipper_class[_n-1]!=""

* 0.03% cusips correspond with multiple crsp_fundno - dropped those
duplicates tag cusip quarter, gen(dup)
drop if dup==1
drop dup

sort cusip quarter

by cusip: gen Lqret=qret[_n-1] if quarter==quarter[_n-1]+1
by cusip: gen Ltnacusip=tna_latest[_n-1] if quarter==quarter[_n-1]+1

keeporder cusip quarter tna_latest broadcat qret avgnav mnav Lmnav fund_name index Lqret Ltnacusip crsp_obj_cd lipper_class ins
ren lipper_class mflipper_class
replace fund_name=upper(fund_name)
save fundq_cusip_2022.dta, replace


******************************************************************************
************************* TDF INDICATORS
/* Import manually cleaned TDF series list, checking against Morningstar TDF list
insheet using "../Data/CRSP MFDB/tdflist_modified.csv", clear
keep crsp_portno fund_name series_name
drop if crsp_portno==.
drop if series_name==""
bys crsp_portno: gen fob=(_n==1)
keep if fob==1
drop fob
save portnolist_series.dta, replace

insheet using "../Data/CRSP MFDB/series_cleanup.csv", clear
codebook crsp_fundno crsp_portno
tab drop, m
codebook series_name1 if drop!=1
drop if drop==1
keep crsp_portno series_name1 
save series_cleanup.dta, replace
insheet using "../Data/CRSP MFDB/series_cleanup_2.csv", clear
codebook crsp_fundno crsp_portno
tab drop, m
codebook series_name2 if drop!=1
drop if drop==1
keep crsp_portno series_name2 
save series_cleanup2.dta, replace
*/

/* Identify TDFs based on fund names
* import new TDF series name cleaned spreadsheet
insheet using "C:\Users\Yang Sun\Dropbox\TDF\Data\CRSP MFDB\series_cleanup_new2023.csv", clear
keeporder crsp_portno series_name1 
ren series_name1 series_name2
save series_cleanup_new2023.dta, replace
*/


use fundq_2018_2022, clear
sort crsp_fundno quarter
drop if crsp_portno==.

sort crsp_fundno quarter
by crsp_fundno: gen fob=(_n==1)

** 2000 target
gen td2000=1 if (strpos(fund_name,"2000")!=0) & (strpos(fund_name,"Russell 2000")==0 & strpos(fund_name,"Russ 2000")==0 &  strpos(fund_name,"Russell2000")==0)
* corrections - clearly non-target date funds
replace td2000=. if strpos(fund_name,"2000+")!=0 | strpos(fund_name,"V2000")!=0 | strpos(fund_name,"AXA Tactical")!=0 | strpos(fund_name,"AXA 2000")!=0 | strpos(fund_name,"2000 ETF")!=0 | strpos(fund_name,"Focused 2000 Value")!=0
l fund_name if td2000==1 & fob==1
/*some seems to be target maturity fixed income funds, will adjust later to make sure those are not classified as TDFs */
drop fob

*** other target dates
** latest is 2070?
foreach var in 2005 2010 2015 2020 2025 2030 2035 2040 2045 2050 2055 2060 2065 2070 {
gen td`var'=1 if strpos(fund_name,"`var'")!=0
}

*** TDF indicator
gen tdf=1 if td2000==1
foreach var in 2005 2010 2015 2020 2025 2030 2035 2040 2045 2050 2055 2060 2065 2070 {
replace tdf=1 if td`var'==1
}

gen tgyr=.
foreach var in 2000 2005 2010 2015 2020 2025 2030 2035 2040 2045 2050 2055 2060 2065 2070 {
replace tgyr=`var' if td`var'==1
}

* clean up TDFs and organize by series
sort crsp_portno quarter crsp_fundno
replace tdf=0 if tdf==.

* by crsp_portno quarter: assert tdf==tdf[_n-1] if tdf[_n-1]!=.
* yes

* some TDFs are converted from other funds, the history before conversion should not be considered TDF
* Fidelity income replacement funds renamed in 2017 to be retirement funds, also shouldn't be considered TDF before the name change
* other cases [BlackRock, NestEgg, John Hancock, Deutsche, Pimco] names will be convered to (e.g.) "retirement active" without the target year after the target year has been reached. Treat these as TDFs

sort crsp_fundno quarter
by crsp_fundno: replace tdf=tdf[_n-1] if tdf[_n-1]==1 & (crsp_fundno==46166 | crsp_fundno==5246 | crsp_fundno==13145 | crsp_fundno==37215 | crsp_fundno==49268 | crsp_fundno==59074  ) 

*** copy within fund-quarter
bys crsp_portno quarter: egen tdf0=max(tdf)
drop tdf
ren tdf0 tdf

sort crsp_portno quarter crsp_fundno
** last special case: BMO, the share class once classified as TDF was terminated
by crsp_portno: replace tdf=tdf[_n-1] if tdf[_n-1]==1 & crsp_portno==1033134

joinby crsp_portno using series_cleanup, unm(b)
tab _m

codebook series_name1 if _m==1
codebook series_name1 if _m==3
drop _m

joinby crsp_portno using series_cleanup2, unm(b)
tab _m

tab _m if series_name1=="" & series_name2!=""
replace series_name1=series_name2 if _m==3
drop _m
drop series_name2

/** save spreadsheet for manual cleaning
keep if series_name1=="" & tgyr!=.
sort crsp_portno quarter 
by crsp_portno: gen fob=(_n==1)
keep if fob==1
keeporder crsp_portno fund_name inception_month series_name1 tgyr 
*/

joinby crsp_portno using series_cleanup_new2023, unm(b)
tab _m
tab _m if series_name1=="" & series_name2!=""
replace series_name1=series_name2 if _m==3
drop _m
drop series_name2

** clean up TDF identifiers
replace tdf=0 if series_name1==""
replace tgyr=. if series_name1==""

replace tdf=1 if series_name1!=""
tab tgyr if series_name1!="", m /* still have some missing, which is ok */

tab tgyr tdf, m
codebook series_name1 if tdf==1 /*111 series*/
save fundq_2018_2022_1.dta, replace

* separately save series names for each TDF
use fundq_2018_2022_1, clear
keep if series_name1!=""
keep crsp_portno series_name1
duplicates drop
duplicates report crsp_portno
save portno_series_2022.dta, replace


******************************************************************************
************************* MUTUAL FUND LEVEL QUARTERLY PANEL
*** Data on cash holdings
use "../Data/CRSP MFDB/MFcash20182022.dta", clear
sort crsp_fundno caldt
gen quarter=qofd(caldt)
format quarter %tq
drop summary_period2 caldt
duplicates drop
sort crsp_portno quarter crsp_fundno
keep crsp_portno quarter per_cash
duplicates drop
drop if crsp_portno==.
gen year=yofd(dofq(quarter))
collapse (mean)per_cash, by(crsp_portno year)
replace per_cash=per_cash/100
su per_cash, d
save portnocash2022.dta, replace

*** quarterly returns and expense ratios aggregate up from share class to fund level
use fundq_2018_2022_1, clear
sort crsp_fundno quarter
by crsp_fundno: gen Ltna=tna_latest[_n-1] if quarter==quarter[_n-1]+1

su qret, d
su exp_ratio, d

winsor exp_ratio 

foreach var of varlist qret exp_ratio {
gen w=`var'*Ltna
egen ww=sum(w) if w<., by(crsp_portno quarter)
egen www=median(ww), by(crsp_portno quarter)
egen t=sum(Ltna) if w<., by(crsp_portno quarter)
egen tt=median(t), by(crsp_portno quarter)
gen w`var'=www/tt
replace w`var'=. if w`var'==0
drop w ww www t tt
}
collapse (mean)wqret (mean)wexp_ratio, by(crsp_portno quarter)
save wqret2022.dta, replace

*** Other characteristics
use fundq_2018_2022_1, clear
* make sure TDF indicator is consistent across shares of the same fund
by crsp_portno quarter: assert tdf==tdf[_n-1] if tdf[_n-1]!=. & crsp_portno!=.
by crsp_portno quarter: egen medtgyr=median(tgyr)
replace tgyr=medtgyr if tgyr==.
by crsp_portno quarter: assert tgyr==tgyr[_n-1] if tgyr[_n-1]!=. & crsp_portno!=.

* Fund TNA
by crsp_portno quarter: egen fdtna=sum(tna_latest) if crsp_portno!=.

* Fund age: keep earliest inception year
by crsp_portno: egen incyr=min(yofd(dofm(inception_month)))

* keep the largest share class of each fund
gen tmp=-tna_latest
sort crsp_portno quarter tmp
by crsp_portno quarter: gen fob=(_n==1)
keep if fob==1
keep crsp_portno quarter tdf tgyr fdtna incyr

joinby crsp_portno quarter using fundqtrfixed22

sort crsp_portno quarter
by crsp_portno: gen Lfdtna=fdtna[_n-1] if quarter==quarter[_n-1]+1

joinby crsp_portno quarter using wqret2022

gen dollarflow=fdtna-Lfdtna*(1+wqret)
gen fdflowpct=dollarflow/Lfdtna
winsor fdflowpct
sort crsp_portno quarter
foreach var in fdflowpct wqret {
by crsp_portno: gen L`var'=`var'[_n-1] if quarter==quarter[_n-1]+1
}
gen year=yofd(dofq(quarter))
joinby crsp_portno year using portnocash2022, unm(b) 
tab _m
keep if _m==1 | _m==3
drop _m
save portno_quarterly_2022.dta, replace


******************************************************************************
************************* TDF HOLDINGS DATA
/* crsp_portno list for downloading TDF holdings
use fundq_2018_2022_1, clear
codebook crsp_portno if tdf==1
keep if tdf==1
keep crsp_portno
duplicates drop
export delimited crsplist_18to22.txt, replace
*/
/* how many TDF-quarters have quarter-end holding available?
use "../Data/CRSP MFDB/TDF_holding_200103_201903.dta", clear /*only downloaded for TDFs*/
drop if cusip=="" | crsp_portno==. | report_dt==. | nbr_shares==.
gen quarter=qofd(report_dt)
* keep the reporting dates in March, June, September, and December.
bys crsp_portno quarter cusip: egen maxdt=max(report_dt)
keep if abs(report_dt-maxdt)<0.1
gen month=month(report_dt)
tab month, m
gen qend=(month==3 | month==6 | month==9 | month==12)
tab qend, m
collapse (max)qend, by(crsp_portno quarter)
su qend, d*/

/** explore frequency of reporting of holdings data
use "../Data/CRSP MFDB/TDF_holding_201801_202212.dta", clear /*only downloaded for TDFs*/
drop if cusip=="" | crsp_portno==. | report_dt==. | nbr_shares==.
gen ym=mofd(report_dt)
format ym %tm
collapse (sum)market_val, by(ym)
line market_val ym
gen month=month(dofm(ym))
line market_val ym if month==3 | month==6 | month==9 | month==12
*/

*** Main processing
use "../Data/CRSP MFDB/TDF_holding_201801_202303.dta", clear /*only downloaded for TDFs*/
gen quarter=qofd(report_dt)
bys crsp_portno quarter cusip: egen maxdt=max(report_dt)
keep if abs(report_dt-maxdt)<0.1
collapse (mean)nbr_shares market_val, by(crsp_portno cusip quarter)

* Add TDF names, target years 
joinby crsp_portno quarter using portno_quarterly_2022, unm(b) 
keep if _m==3 
drop _m
codebook crsp_portno
ren fund_name tdffdname
drop tdf
ren tgyr tdftgyr
ren index tdfindex 
drop mgmt_cd crsp_obj_cd
drop broadcat

* merge with data on underlying MFs
joinby cusip quarter using fundq_cusip_2022, unm(b)
tab _m
keep if _m==1 | _m==3
drop _m
order crsp_portno quarter cusip broadcat 

* drop the unidentified cusip
drop if broadcat==""
codebook cusip
format quarter %tq
* keep only equity and bond fund holdings 
drop if broadcat=="mixed"

save tdfholdings_2022.dta, replace







********************************************************
*** TDF holdings availability in aggregate 
use portno_quarterly_2022, clear
tab tdf, m
keep if tdf==1
collapse (sum)fdtna , by(quarter)
save tdftotal22.dta, replace

use tdfholdings_2022, clear
sort crsp_portno quarter cusip
order crsp_portno quarter cusip fdtna market_val
collapse (sum)market_val, by (quarter)
*** convert units to billions
replace market_val=market_val/1000000000

joinby quarter using tdftotal22
replace fdtna=fdtna/1000

label var fdtna "Total assets"
label var market_val "Total holdings available"
line fdtna market_val quarter, scheme(s2mono) xtitle("Year-quarter") ytitle("$ Billion") graphregion(color(white)) bgcolor(white)
gr export "../Writing/HoldingtoAssets2022.png", replace
gen frac=market_val/fdtna
* good data coverage through 2022Q4

****** Holdings data cleaning
use tdfholdings_2022, clear
keep if quarter>=yq(2018,1) & quarter<=yq(2022,4)
sort crsp_portno quarter cusip

* how much of the underlying fund share class is owned by a TDF
gen pct=market_val/(1000000*tna_latest)
su pct, d
* should be less than 1
drop if pct>1 | pct<0 

* available holdings as a fraction of TDF fund size
by crsp_portno quarter: egen sumholding=sum(market_val)
gen pctholdingavail=sumholding/(1000000*fdtna)
by crsp_portno quarter: gen fob=(_n==1)
su pctholdingavail if fob==1, d
* available holdings including cash holdings
gen pctholdingavail1=pctholdingavail+per_cash

* Apply restriction: available holdings must be below 110% of the fund TNA and above 50%
drop if pctholdingavail1>1.1 | pctholdingavail1<0.5
tab tdftgyr if fob==1, su(pctholdingavail1)

** calculate summ stats of holdings
* number of funds held
by crsp_portno quarter: egen numfd=count(cusip)

* classify TDFs into active and passive by underlying holdings
bys crsp_portno quarter index: egen tmpsum=sum(market_val)
replace tmpsum=. if index==0
by crsp_portno quarter: egen indxsum=median(tmpsum)
replace indxsum=0 if indxsum==.
by crsp_portno quarter: egen totsum=sum(market_val)

gen frindx=indxsum/totsum /*fraction of index funds out of total mutual fund holdings*/
gen frindx1=indxsum/(fdtna*1000000) /*fraction of index funds out of TNA*/

drop if frindx1==.

gen passivetdf=(frindx>=0.5) /* passive TDF identifier based on fraction of index fund holding out of all MFs held by the TDF */

su passivetdf if fob==1, d
label var frindx "Fraction Assets Invested in Index Funds"
histogram frindx if fob==1 & pctholdingavail1>0.9, frac  graphregion(color(white)) bgcolor(white)
gr export "../Writing/fracindx2022.png", replace
drop tmpsum indxsum totsum
save tdfholdings1_2022.dta, replace

*** separately save passive v active TDF indicators
use tdfholdings1_2022, clear
keep if fob==1
tab passivetdf, su(pctholdingavail)
ttest pctholdingavail, by(passivetdf)
keep crsp_portno quarter frindx passivetdf
save tdfactpas2022.dta, replace

********* Series level controls
* Active/passive indicator by series
use tdfholdings1_2022, clear
keep if fob==1
joinby crsp_portno using portno_series_2022, unm(b)
tab _m
drop if _m==2
drop _m
collapse (sum)fdtna (mean)passivetdf, by(series_name1 quarter)
drop if series_name1==""
gsort -fdtna
gen passive0=(passivetdf>0.5)
drop passivetdf
ren passive0 passiveseries
keep series_name1 quarter passiveseries fdtna
ren fdtna seriessize
save passiveseries2022.dta, replace






******************************************************************
*************************** ASSET CLASS RETURNS
*** Monthly benchmark returns
use "../Data/CRSP MFDB/mret_tna_201801_202212.dta", clear
gen ym=mofd(caldt)
format ym %tm
replace mtna=. if mtna==-99
collapse (mean)mtna mret mnav, by(crsp_fundno ym)
* add expense ratios
gen quarter=qofd(dofm(ym))
joinby crsp_fundno quarter using fundq_2018_2022
keeporder crsp_fundno ym mtna mret exp_ratio
* Keep Vanguard bond and international index funds
keep if crsp_fundno==31239 | crsp_fundno==31200
keep crsp_fundno ym mret exp_ratio
sort crsp_fundno ym
* fill in the missing expense ratio
by crsp_fundno: replace exp_ratio=exp_ratio[_n-1] if exp_ratio==. & exp_ratio[_n-1]!=.
forvalues i=1/20{
by crsp_fundno: replace exp_ratio=exp_ratio[_n+`i'] if exp_ratio==. & exp_ratio[_n+`i']!=.
}
gen pfmret=mret+exp_ratio/12
codebook mret pfmret
gen bmindx="VGBond" if crsp_fundno==31239
replace bmindx="VGIntl" if crsp_fundno==31200
keep bmindx ym mret pfmret
ren mret bmmret
ren pfmret bmpfmret
save benchmarkreturns2022_monthly.dta, replace

insheet using "../Data/CRSP Stock/FF3_monthly_2022.csv", clear 
tostring date, replace
gen ym=mofd(date(date,"YM"))
format ym %tm
gen mkt=mktrf+rf
keep ym mkt rf
replace mkt=mkt/100
replace rf=rf/100
drop rf 

gen bmindx="StkMktincl"
ren mkt bmpfmret
keep bmindx ym bmpfmret

append using benchmarkreturns2022_monthly

sort bmindx ym
keep if ym>=ym(2018,1) & ym<=ym(2022,12)
keeporder bmindx ym bmpfmret 

reshape wide bmpfmret, i(ym) j(bmindx) string
sort ym

ren bmpfmretStkMktincl bmpfmretdom_eq
ren bmpfmretVGBond bmpfmretfixed_inc
ren bmpfmretVGIntl bmpfmretfor_eq

foreach var of varlist bmpfmret* {
gen L`var'=`var'[_n-1] if ym==ym[_n-1]+1
forvalues i=2/5{
gen L`i'`var'=`var'[_n-`i'] if ym==ym[_n-`i']+`i'
}
}
*save "C:\Users\YangSun\Dropbox\Typos\Output\benchmarkmonthly_long.dta", replace
save benchmarkmonthly2022.dta, replace

*******************************************************************************
****************** TDF ownership in mutual funds
* First step: calculate TDF ownership at CUSIP (share class) level
use tdfholdings1_2022, clear
*joinby crsp_portno quarter using tdfselection
collapse (sum)pct (sum)market_val (mean)tna_latest, by(cusip quarter)
drop if pct>1 | pct==0
sort cusip quarter
by cusip: gen Lpct=pct[_n-1] if quarter==quarter[_n-1]+1
save cusip_tdf_ownership_2022.dta, replace /*cusip+quarter level overall TDF ownership*/

* active TDFs
use tdfholdings1_2022, clear 
*joinby crsp_portno quarter using tdfselection
* Add indicators for active vs passive TDFs
joinby crsp_portno quarter using tdfactpas2022
joinby crsp_portno using portno_series_2022, unm(b)
keep if _m==1 | _m==3
drop _m
joinby series_name1 using passiveseries2022, unm(b)
keep if _m==1 | _m==3
drop _m
keep if passiveseries==0
collapse (sum)pct (sum)market_val (mean)tna_latest, by(cusip quarter)
drop if pct>1 | pct==0
sort cusip quarter
by cusip: gen Lpct=pct[_n-1] if quarter==quarter[_n-1]+1
save cusip_tdf_ownership_2022_act.dta, replace /*cusip+quarter level active TDF ownership*/

* passive TDFs
use tdfholdings1_2019, clear
*joinby crsp_portno quarter using tdfselection
joinby crsp_portno quarter using tdfactpas2022
joinby crsp_portno using portno_series_2022, unm(b)
keep if _m==1 | _m==3
drop _m
joinby series_name1 using passiveseries2022, unm(b)
keep if _m==1 | _m==3
drop _m
keep if passivetdf==1
collapse (sum)pct (sum)market_val (mean)tna_latest, by(cusip quarter)
drop if pct>1 | pct==0
sort cusip quarter
by cusip: gen Lpct=pct[_n-1] if quarter==quarter[_n-1]+1
save cusip_tdf_ownership_2022_pas.dta, replace /*cusip+quarter level passive TDF ownership*/

* Second step: moving from share class to fund, TDF ownership at fund level
* cusip-portno bridge
use fundq_2018_2022, clear
keep cusip8 quarter crsp_portno
drop if cusip8==""
duplicates drop
duplicates tag cusip8 quarter, gen(dup)
keep if dup==0
drop dup
ren cusip8 cusip
ren crsp_portno cusipportno
save cusip_portno_2022.dta, replace

* overall TDF ownership	
use cusip_tdf_ownership_2022, clear 
joinby cusip quarter using cusip_portno_2022
* sum TDF holding value to fund level
collapse (sum)market_val, by(cusipportno quarter)
* add in fund size
ren cusipportno crsp_portno
joinby crsp_portno quarter using portno_quarterly_2022
gen fdpct=market_val/(fdtna*1000000)
* fill the time series for 2008Q2-2018Q4
sort crsp_portno quarter
by crsp_portno: egen minquarter=min(quarter)
by crsp_portno: egen maxquarter=max(quarter)
fillin crsp_portno quarter
sort crsp_portno quarter
foreach var in min max{
by crsp_portno: egen `var'qtr0=median(`var'quarter)
}
order crsp_portno quarter _fillin minqtr0 maxqtr0
* fill missing values
by crsp_portno: replace fdpct=fdpct[_n-1] if fdpct==. & fdpct[_n-1]!=.
keep if quarter>=minqtr0 & quarter<=maxqtr0
keep crsp_portno quarter fdpct broadcat
sort crsp_portno quarter
by crsp_portno: gen Lfdpct=fdpct[_n-1] if quarter==quarter[_n-1]+1
save cusipportno_tdf_ownership_2022, replace

* passive TDF ownership	
use cusip_tdf_ownership_2022_pas, clear 
joinby cusip quarter using cusip_portno_2022
* sum TDF holding value to fund level
collapse (sum)market_val, by(cusipportno quarter)
* add in fund size
ren cusipportno crsp_portno
joinby crsp_portno quarter using portno_quarterly_2022
gen fdpct=market_val/(fdtna*1000000)
* fill the time series for 2008Q2-2018Q4
sort crsp_portno quarter
by crsp_portno: egen minquarter=min(quarter)
by crsp_portno: egen maxquarter=max(quarter)
fillin crsp_portno quarter
sort crsp_portno quarter
foreach var in min max{
by crsp_portno: egen `var'qtr0=median(`var'quarter)
}
order crsp_portno quarter _fillin minqtr0 maxqtr0
* fill missing values
by crsp_portno: replace fdpct=fdpct[_n-1] if fdpct==. & fdpct[_n-1]!=.
keep if quarter>=minqtr0 & quarter<=maxqtr0
keep crsp_portno quarter fdpct broadcat
sort crsp_portno quarter
by crsp_portno: gen Lfdpct=fdpct[_n-1] if quarter==quarter[_n-1]+1
save cusipportno_tdf_ownership_2022_pas, replace

* active TDF ownership	
use cusip_tdf_ownership_2022_act, clear 
joinby cusip quarter using cusip_portno_2022
* sum TDF holding value to fund level
collapse (sum)market_val, by(cusipportno quarter)
* add in fund size
ren cusipportno crsp_portno
joinby crsp_portno quarter using portno_quarterly_2022
gen fdpct=market_val/(fdtna*1000000)
* fill the time series for 2008Q2-2018Q4
sort crsp_portno quarter
by crsp_portno: egen minquarter=min(quarter)
by crsp_portno: egen maxquarter=max(quarter)
fillin crsp_portno quarter
sort crsp_portno quarter
foreach var in min max{
by crsp_portno: egen `var'qtr0=median(`var'quarter)
}
order crsp_portno quarter _fillin minqtr0 maxqtr0
* fill missing values
by crsp_portno: replace fdpct=fdpct[_n-1] if fdpct==. & fdpct[_n-1]!=.
keep if quarter>=minqtr0 & quarter<=maxqtr0
keep crsp_portno quarter fdpct broadcat
sort crsp_portno quarter
by crsp_portno: gen Lfdpct=fdpct[_n-1] if quarter==quarter[_n-1]+1
save cusipportno_tdf_ownership_2022_act, replace

** Combine together different ownership measures
use portno_quarterly_2022, clear
keep if quarter>=yq(2018,1) & quarter<=yq(2022,4)
joinby crsp_portno quarter using cusipportno_tdf_ownership_2022, unm(b)
keep if _m==1 | _m==3
drop _m
ren fdpct tdfallpct
drop Lfdpct
sort crsp_portno quarter
by crsp_portno: replace tdfallpct=tdfallpct[_n-1] if tdfallpct==. & tdfallpct[_n-1]!=.
replace tdfallpct=0 if tdfallpct==.
joinby crsp_portno quarter using cusipportno_tdf_ownership_2022_act, unm(b)
keep if _m==1 | _m==3
drop _m
ren fdpct tdfactpct
drop Lfdpct
sort crsp_portno quarter
by crsp_portno: replace tdfactpct=tdfactpct[_n-1] if tdfactpct==. & tdfactpct[_n-1]!=.
replace tdfactpct=0 if tdfactpct==.
joinby crsp_portno quarter using cusipportno_tdf_ownership_2022_pas, unm(b)
keep if _m==1 | _m==3
drop _m
ren fdpct tdfpaspct
drop Lfdpct
sort crsp_portno quarter
by crsp_portno: replace tdfpaspct=tdfpaspct[_n-1] if tdfpaspct==. & tdfpaspct[_n-1]!=.
replace tdfpaspct=0 if tdfpaspct==.
foreach var in tdfallpct tdfactpct tdfpaspct{
by crsp_portno: gen L`var'=`var'[_n-1] if quarter==quarter[_n-1]+1
}
save tdfownership_quarterly2022.dta, replace


*** Calculate the % of the agg dom eq fund sector held by TDFs
use tdfownership_quarterly2022, clear
su tdfallpct, d
tab broadcat, m
keep if broadcat=="dom_eq"
su tdfallpct, d
gen wttdfallpct=fdtna*tdfallpct
collapse (sum)wttdfallpct (sum)fdtna (mean)tdfallpct, by(quarter)
replace wttdfallpct=wttdfallpct/fdtna




**************************************************************************************
**************************** Mutual funds monthly panel
* calculate fund family size
use "../Data/CRSP MFDB/mret_tna_201801_202212.dta", clear
gen ym=mofd(caldt)
format ym %tm
replace mtna=. if mtna==-99
collapse (mean)mtna mret mnav, by(crsp_fundno ym)
* fund family indicators
gen quarter=qofd(dofm(ym))
joinby crsp_fundno quarter using fundq_2018_2022
keeporder crsp_fundno ym mtna mgmt_cd2
collapse (sum)ffsize=mtna, by(mgmt_cd2 ym)
drop if mgmt_cd2==""
save ffsize1_2022.dta, replace

* quarterly version
use ffsize1_2022, clear
gen quarter=qofd(dofm(ym))
gen month=month(dofm(ym))
keep if month==3 | month==6 | month==9 | month==12
keep mgmt_cd2 quarter ffsize
sort mgmt_cd2 quarter
save ffsizeq_2022, replace

*** main monthly panel
use "../Data/CRSP MFDB/mret_tna_201801_202212.dta", clear
gen ym=mofd(caldt)
format ym %tm
replace mtna=. if mtna==-99
collapse (mean)mtna mret mnav, by(crsp_fundno ym)
winsor mret
sort crsp_fundno ym

* 12-m volatility
su ym if ym==ym(2019,1)
su ym if ym==ym(2022,12)

gen sd1yr=.
forvalues i=707/755 {
display `i'
gen tmp=1 if ym>=`i'-11 & ym<=`i'
by crsp_fundno: egen sumtmp=sum(tmp)
by crsp_fundno: egen sd=sd(mret) if tmp==1
replace sd1yr=sd if ym==`i' & sumtmp==12
drop tmp sumtmp sd
}
replace sd1yr=. if sd1yr==0
* monthly dollar flows
sort crsp_fundno ym
replace mtna=. if mtna==-99
by crsp_fundno: gen Lmtna=mtna[_n-1] if ym==ym[_n-1]+1
gen mflow=mtna-Lmtna*(1+mret)
gen mflowpct=mflow/Lmtna

gen quarter=qofd(dofm(ym))
sort crsp_fundno ym
by crsp_fundno: gen Lmret=mret[_n-1] if ym==ym[_n-1]+1
gen lnLtna=ln(Lmtna)

* add other quarterly controls
joinby crsp_fundno quarter using fundq_2018_2022_1, unm(b)
keep if _m==1 | _m==3
drop _m

joinby mgmt_cd2 ym using ffsize1_2022, unm(b)
replace ffsize=. if mgmt_cd2==""
drop if _m==2
drop _m

sort crsp_fundno ym
by crsp_fundno: gen Lffsize=ffsize[_n-1] if ym==ym[_n-1]+1
gen lnLffsize=ln(Lffsize)

gen agem=ym-inception_month
su agem, d
drop if agem<0
gen lnage=ln(agem)
su exp_ratio, d
by crsp_fundno: gen Lsd1yr=sd1yr[_n-1] if ym==ym[_n-1]+1
by crsp_fundno: gen Lmflowpct=mflowpct[_n-1] if ym==ym[_n-1]+1

replace tdf=0 if tdf==.

joinby crsp_portno quarter using fundqtrfixed22, unm(b)
keep if _m==1 | _m==3
drop _m
tab broadcat, m
drop if broadcat==""
save monthlydata2022.dta, replace


** aggregate from share class to fund level
use monthlydata2022, clear 
sort crsp_portno ym
foreach var of varlist sd1yr exp_ratio mret {
gen w=`var'*Lmtna
egen ww=sum(w) if w<., by(crsp_portno ym)
egen www=median(ww), by(crsp_portno ym)
egen t=sum(Lmtna) if w<., by(crsp_portno ym)
egen tt=median(t), by(crsp_portno ym)
gen w`var'=www/tt
replace w`var'=. if w`var'==0
drop w ww www t tt
}
* institutional indicator
bys crsp_portno ym ins: egen tmpsum=sum(mtna)
gen tmpsum0=tmpsum if ins==0
gen tmpsum1=tmpsum if ins==1
by crsp_portno ym: egen retsize=median(tmpsum0)
by crsp_portno ym: egen inssize=median(tmpsum1)
by crsp_portno ym: egen totsize=sum(mtna)
replace retsize=0 if retsize==.
replace inssize=0 if inssize==.
gen insshr=inssize/totsize
* collapse to fund level
collapse (mean)wmret (sum)fdtna=mtna (mean)ffsize (min)inception_month (mean)wexp_ratio (mean)wsd1yr (mean)insshr (mean)index (mean)etf, by(crsp_portno broadcat ym)
duplicates report crsp_portno ym
gen fdins=(ins>0.5)
tab fdins, m

* calculate monthly FUND flow
sort crsp_portno ym
by crsp_portno: gen Lfdtna=fdtna[_n-1] if ym==ym[_n-1]+1
gen mflow=fdtna-Lfdtna*(1+wmret)
gen mflowpct=mflow/Lfdtna

gen lnLfdtna=ln(Lfdtna)

sort crsp_portno ym
by crsp_portno: gen Lffsize=ffsize[_n-1] if ym==ym[_n-1]+1
gen lnLffsize=ln(Lffsize)

gen age=yofd(dofm(ym))-yofd(dofm(inception_month))+1
keep if age>=1
gen lnage=ln(age)

gen quarter=qofd(dofm(ym))
format quarter %tq

joinby crsp_portno quarter using tdfownership_quarterly2022, unm(b)
tab _m /*no _m==1*/
drop if _m==2
drop _m

keep if quarter>=yq(2018,1) & quarter<=yq(2022,4)

* add broad category benchmark returns
joinby ym using benchmarkmonthly2022

* differential asset class returns
gen mkt=bmpfmretdom_eq
gen diffret=mkt-bmpfmretfixed_inc

gen Lmkt=Lbmpfmretdom_eq
gen Ldiffret=Lmkt-Lbmpfmretfixed_inc
gen L2diffret=L2bmpfmretdom_eq-L2bmpfmretfixed_inc

foreach var in diffret Ldiffret L2diffret {
gen `var'_Ltdfallpct=`var'*Ltdfallpct
gen `var'_Ltdfactpct=`var'*Ltdfactpct
gen `var'_Ltdfpaspct=`var'*Ltdfpaspct
}
*drop if fdins==1
drop if Lfdtna<10
*drop if mflowpct<-.9 | mflowpct>10

sort crsp_portno ym
by crsp_portno: gen Lmflowpct=mflowpct[_n-1] if ym==ym[_n-1]+1
by crsp_portno: gen Lwsd1yr=wsd1yr[_n-1] if ym==ym[_n-1]+1
drop if tdf==1
save monthlydata_portno_forreg_2022.dta, replace

*** agg TDF holding of the dom eq fund sector
use monthlydata_portno_forreg_2022, clear
su tdfallpct, d
tab broadcat, m
keep if broadcat=="dom_eq"
su tdfallpct, d
gen wttdfallpct=fdtna*tdfallpct
collapse (sum)wttdfallpct (sum)fdtna (mean)tdfallpct, by(quarter)
replace wttdfallpct=wttdfallpct/fdtna
* 5% in 2019Q4

*** similar calculation of agg TDF holding of the dom eq fund sector in 2008
use monthlydata_portno_forreg_2019, clear
su tdfallpct, d
tab broadcat, m
keep if broadcat=="dom_eq"
su tdfallpct, d
gen wttdfallpct=fdtna*tdfallpct
collapse (sum)wttdfallpct (sum)fdtna (mean)tdfallpct, by(quarter)
replace wttdfallpct=wttdfallpct/fdtna

*** keep portno list of all domestic equity funds
use monthlydata_portno_forreg_2022, clear
keep if broadcat=="dom_eq"
keeporder crsp_portno quarter
save domeq_portnolist.dta, replace


*******************************************************************
**************** Stock level indirect TDF ownership
* domestic equity MFs with positive TDF ownership
use cusipportno_tdf_ownership_2022, clear
keep if broadcat=="dom_eq"
keep crsp_portno quarter fdpct
save cusipportno_tdf_ownership_domeq_2022.dta, replace

*** TDF-held MF holdings of stocks and stock-level TDF ownership
* list of domestic equity funds with positive TDF ownership 
use cusipportno_tdf_ownership_domeq_2022, clear
keep crsp_portno quarter fdpct
ren fdpct tdfpct
format quarter %tq
keep if quarter>=yq(2018,1) & quarter<=yq(2022,3)
* keep only portno 
keep crsp_portno
duplicates drop
save TRportnolist_2022.dta, replace


*** List of all domestic equity funds, unconditional on TDF ownership
* domeq_portnolist

*** Understand MFLINKS and frequency of changes
use "C:\Users\Yang Sun\Dropbox\TDF\Data\MFLINK\mflink2_2023", clear
order fundno fdate wficn
drop rdate
* keep the latest non-missing wficn for each TR fundno
drop if wficn==.
sort fundno fdate
by fundno: egen max=max(fdate)
keep if fdate==max
keep fundno wficn
save mflink2a_2023.dta, replace

*** Map PORTNO to TR Fundno using MFLINKS
use fundq_2018_2022, clear
keep crsp_fundno quarter crsp_portno
* restricting holdings data to MFs with positive TDF ownership
joinby crsp_portno using TRportnolist_2022

* add WFICN
joinby crsp_fundno using "C:\Users\Yang Sun\Dropbox\TDF\Data\MFLINK\mflink1_2023"
drop crsp_fundno /* drop share class indicator*/
duplicates drop
duplicates tag crsp_portno quarter, gen(dup)
tab dup
drop if dup!=0 /*2% obs*/
drop dup
save portno_wficn_bridge_2022.dta, replace

* TDF-invested wficn list (to reduce size of TR holdings data)
use portno_wficn_bridge_2022, clear
keep wficn
duplicates drop
save wficnsample_2022.dta, replace

**** to download holdings of all dom eq funds (larger set than those held by TDFs)
use fundq_2018_2022, clear
keep crsp_fundno quarter crsp_portno
joinby crsp_portno quarter using domeq_portnolist
joinby crsp_fundno using "C:\Users\Yang Sun\Dropbox\TDF\Data\MFLINK\mflink1_2023"
drop crsp_fundno /* drop share class indicator*/
duplicates drop
duplicates tag crsp_portno quarter, gen(dup)
tab dup
drop if dup!=0 /*1% obs*/
drop dup
save portno_wficn_bridge_DOMEQ.dta, replace
* DOMEQ wficn list (to reduce size of TR holdings data)
use portno_wficn_bridge_DOMEQ, clear
keep wficn
duplicates drop
save wficnsampleDOMEQ_2022.dta, replace

*********************************************************
************************ clean up MF stock holding data
use "../Data/Thomson Reuters/TRholdings_201803_202206.dta", clear
joinby fundno using mflink2a_2023

joinby wficn using wficnsample_2022

gen quarter=qofd(fdate)

* for each quarter, keep the latest filing date
bys fundno quarter cusip: egen maxdt=max(fdate)
keep if abs(fdate-maxdt)<0.1 /*nothing dropped */

* get rid of duplicate observations
collapse (mean)shares, by(wficn cusip quarter)
format quarter %tq
save TRholdings_2022.dta, replace

***** version 2 for all DOMEQ funds
use "../Data/Thomson Reuters/TRholdings_201803_202206.dta", clear
joinby fundno using mflink2a_2023
joinby wficn using wficnsampleDOMEQ_2022
gen quarter=qofd(fdate)
* for each quarter, keep the latest filing date
bys fundno quarter cusip: egen maxdt=max(fdate)
keep if abs(fdate-maxdt)<0.1 /*nothing dropped */
* get rid of duplicate observations
collapse (mean)shares, by(wficn cusip quarter)
format quarter %tq
save TRholdingsDOMEQ_2022.dta, replace



**************************************************************************
*********************************** STOCK SAMPLE
*** start with stock monthly data long panel, then collapse to stock quarterly to calculate TDF ownership

use "../Data/CRSP Stock/stockmonthly_2018_2022.dta", clear
codebook date
gen ym=mofd(date)
gen quarter=qofd(date)
format ym %tm
format quarter %tq

rename *, lower
order cusip permno ym quarter date
*** keep share codes = 10 or 11
tab shrcd, m
keep if shrcd==10 | shrcd==11
/*Share Code: First Digit: 1 = Ordinary Common shares, 3 = ADR, 4 = Shares of Beneficial Interest, 7 = Unit or Limited Partnership. Second Digit: 0 = No special status found, 1 = No special status necessary, 2 = Foreign incorporated, 4 = Closed End Fund, 8 = REIT */

*** keep NYSE, AMEX and NASDAQ
tab exchcd
keep if exchcd==1 | exchcd==2 | exchcd==3
keep cusip ym quarter divamt prc vol ret shrout exchcd siccd

replace divamt=. if divamt==0 /* will replace to zero later - this is to get rid of some duplicate dividend data */
replace prc=-prc if prc<0
su prc, d

*** get rid of duplicate obs
collapse (mean)divamt prc vol ret shrout exchcd (median)siccd, by(cusip ym)
* shrout recorded in thousands
* VOL is the sum of the trading volumes during that month, expressed in 100 shares  

gen quarter=qofd(dofm(ym))
format quarter %tq

sort cusip ym
by cusip: gen Lprc=prc[_n-1] if ym==ym[_n-1]+1
replace divamt=0 if divamt==.
gen mret=(prc+divamt)/Lprc-1
corr mret ret /*corr is only 0.34 because haven't dropped outliers, corr will rise to 0.97 after winsorizing both*/
* use ret for rest of analysis, have fewer missing values

* normalize volume by number of shares outstanding
replace vol=vol*100
replace vol=vol/(shrout*1000)
save stockmonthly_2022.dta, replace


****** ME breakpoints
insheet using "../Data/CRSP Stock/ME_Breakpoints_2023.csv", clear
gen ym=ym(int(v1/100),v1-int(v1/100)*100)
format ym %tm
ren v2 num
forvalues i=3/22{
local j=`i'-2
ren v`i' b`j'
}
keep if ym>=ym(1985,1) & ym<=ym(2022,12)
keep ym b*
sort ym
order ym
save nysesizebreak_2023_longer.dta, replace


*******************************************************
****************** Quarterly stock level characteristics
use stockmonthly_2022, clear
gen month=month(dofm(ym))
bys cusip quarter: egen count=count(month)
keep if count==3
drop count

* calculate quarterly returns
su ret, d
drop mret
gen lnret1=ln(ret+1)
by cusip quarter: egen sumlnret1=sum(lnret1)
gen qret=exp(sumlnret1)-1

order cusip ym ret qret
drop ret

bys cusip quarter: egen qvol=sum(vol)
keep if month==3 | month==6 | month==9 | month==12
drop month
gen marketcap=prc*shrout /* in '000*/
drop if marketcap==0 | marketcap==.

joinby ym using nysesizebreak_2023_longer

order cusip ym marketcap b*

* market cap in millions
replace marketcap=marketcap/1000

gen lbbreak=1 if marketcap<=b1

forvalues i=2/20 {
local j=`i'-1
replace lbbreak=`i' if marketcap>b`j' & marketcap<=b`i'
}
replace lbbreak=20 if lbbreak==. & marketcap!=.

drop b1-b20 ym divamt Lprc lnret1 sumlnret1
drop vol
save stockquarterly_2022.dta, replace

* NYSE breakpoints with quarterly dates
use stockquarterly_2022, clear
keeporder cusip quarter lbbreak
save qlbbreak2022.dta, replace

*** calculate quarterly dividends
use stockmonthly_2022, clear
sort cusip quarter ym
by cusip quarter: egen divq=sum(divamt)
gen month=month(dofm(ym))
keep if month==3 | month==6 | month==9 | month==12
sort cusip quarter
forvalues i=1/3{
by cusip: gen L`i'divqdivq=divq[_n-`i'] if quarter==quarter[_n-`i']+`i'
}
gen ttmdiv=divq+L1divq+L2divq+L3divq
keeporder cusip quarter divq prc ttmdiv
by cusip: gen Lprc=prc[_n-1] if quarter==quarter[_n-1]+1
gen divyieldcrsp=divq/(prc)
su divyieldcrsp, d
gen ttmdivyieldcrsp=ttmdiv/prc
keeporder cusip quarter divyieldcrsp ttmdivyieldcrsp
winsor divyieldcrsp
ren quarter fquarter
sort cusip fquarter
by cusip: gen Ldivyieldcrsp=divyieldcrsp[_n-1] if fquarter==fquarter[_n-1]+1
by cusip: gen Lttmdivyieldcrsp=ttmdivyieldcrsp[_n-1] if fquarter==fquarter[_n-1]+1
save divyieldcrsp2022.dta, replace

  *** QUARTERLY firm characteristics from Compustat
use "../Data/Compustat/Compustat_prof_invest_quarterly_2018-2022.dta", clear
keep if fyearq>=2018 & fyearq<=2022
gen fquarter=yq(fyearq,fqtr)
sort cusip fquarter
bys cusip fquarter: egen maxdate=max(datadate)
keep if abs(datadate-maxdate)<0.1
duplicates tag cusip fquarter, gen(dup)
tab dup
keep if dup==0
sort cusip fquarter
replace ceqq=. if ceqq<0
drop if atq==. | ceqq==. | prccq==.

foreach var in atq ceqq {
    by cusip: gen L`var'=`var'[_n-1] if fquarter==fquarter[_n-1]+1
}
foreach var in revtq cogsq xsgaq xintq cdvcy {
	replace `var'=0 if `var'==.
}

*** Profit
gen roeq=(revtq-cogsq-xsgaq-xintq)/Lceqq
*** Investment
gen investmentq=(atq-Latq)/Latq
*** Dividend yield
gen divyieldq=cdvcy/(cshoq*prccq)
*** M/B 
gen mtobq=(cshoq*prccq)/ceqq
winsor roeq
winsor investmentq
winsor divyieldq
winsor mtobq
*** market cap
gen mktcapfquarter=cshoq*prccq

keeporder cusip fquarter atq ceqq cogsq revtq xintq xsgaq roeq investmentq divyieldq mtobq mktcapfquarter
gen cusip8=substr(cusip,1,8)
ren cusip cusip9
ren cusip8 cusip
sort cusip fquarter
foreach var in ceqq cogsq revtq xintq xsgaq roeq investmentq divyieldq mtobq mktcapfquarter{
    by cusip: gen L`var'=`var'[_n-1] if fquarter==fquarter[_n-1]+1
}
save compustat_profinv_quarter_2023.dta, replace

*** Indicator for whether underlying mutual funds are active or index
use portno_quarterly_2022, clear
keeporder crsp_portno quarter index
save portno_index_2022.dta, replace

*******************************************************************
***************** Calculate quarterly TDF ownership at stock level

* start with TR Mutual Fund Stock Holdings
use TRholdings_2022, clear
joinby cusip quarter using stockquarterly_2022

* value of holding
gen val=prc*shares

* percentage held by each TDF-invested mutual fund, out of total shares outstanding
gen pct=shares/(shrout*1000)
su pct, d

*** % of each WFICN owned by TDFs
* Convert WFICN to CRSP_portno
joinby wficn quarter using portno_wficn_bridge_2022

joinby crsp_portno quarter using tdfownership_quarterly2022
drop Ltdf*

****************************************
***** Calculate stock-level indirect ownership
foreach var of varlist tdfallpct-tdfpaspct {
gen u`var'=`var'*pct
}
* add indicator for whether the underlying MF is active or index
joinby crsp_portno quarter using portno_index_2022

sort cusip quarter index
order cusip quarter index
by cusip quarter index: egen utdfpct=sum(utdfallpct)
foreach var in utdfpct {
gen `var'p=`var' if index==1
gen `var'a=`var' if index==0
}

*** further classifications
* passive TDF holding through index funds
* passive TDF holding through active funds
* active TDF holding through index funds
* active TDF holding through active funds
by cusip quarter index: egen utdfpaspctalt=sum(utdfpaspct)
by cusip quarter index: egen utdfactpctalt=sum(utdfactpct)
foreach var in utdfpaspctalt utdfactpctalt {
gen `var'p=`var' if index==1
gen `var'a=`var' if index==0
}
ren utdfpaspctaltp utdfpaspctp
ren utdfpaspctalta utdfpaspcta
ren utdfactpctaltp utdfactpctp
ren utdfactpctalta utdfactpcta

*** STOCK LEVEL 
collapse (sum)utdfallpct-utdfpaspct (mean)utdfpctp (mean)utdfpcta (mean)utdfpaspctp (mean)utdfpaspcta (mean)utdfactpctp (mean)utdfactpcta, by(cusip quarter)

sort cusip quarter
foreach var of varlist utdfallpct-utdfpcta {
by cusip: gen L`var'=`var'[_n-1] if quarter==quarter[_n-1]+1
by cusip: gen L2`var'=`var'[_n-2] if quarter==quarter[_n-2]+2
}
format quarter %tq
save utdfpct_2022.dta, replace

/* For back of envelope calculation: stock level ownership by all dom eq funds
use TRholdingsDOMEQ_2022, clear
** sum up all shares held by all dom eq funds
collapse (sum)shares, by(cusip quarter)
joinby cusip quarter using stockquarterly_2022, unm(b)
tab _m
keep if _m==1 | _m==3
gen shr_defd=shares/(shrout*1000)
su shr_defd, d
drop if shr_defd>1
su shr_defd if quarter==yq(2019,4)
*/


********************************** Stock-Level risk-adjusted returns calculations
*** Current and lagged factor returns
insheet using "../Data/CRSP Stock/FFmom_202301.csv", clear
tostring date, replace
gen ym=mofd(date(date,"YM"))
format ym %tm
drop date
replace mom=mom/100 
save momfactor2023.dta, replace

insheet using "../Data/CRSP Stock/FF3_monthly_2022.csv", clear
foreach var in mktrf smb hml rf{
replace `var'=`var'/100
}
tostring date, replace
gen ym=mofd(date(date,"YM"))
format ym %tm
drop date

joinby ym using momfactor2023

order ym

foreach var in mktrf smb hml mom {
gen L`var'=`var'[_n-1] if ym==ym[_n-1]+1
}

save ff4_monthly_202301.dta, replace


* add 4 factors to monthly stock return panel
* For JPEF, do not use 7 factor, because liquidity factor not updated. can contact Pastor if necessary
use stockmonthly_2022, clear
joinby ym using ff4_monthly_202301
su ret mktrf smb hml mom 
gen retrf=ret-rf
drop if ret==.
save stockmonth_4f_2023.dta, replace


************ Exposure to current factor returns
*** Estimate four-factor model using pre window 1996-2005
*** NO UPDATE NECESSARY
/*use stockmonth_7f, clear
keep if ym>=ym(1996,1) & ym<=ym(2005,12)
statsby _b _se e(r2) e(N), by(cusip) clear: reg retrf mktrf smb hml mom
keep if _eq2_stat_2>=24
ren _b_mktrf b4mkt
ren _b_smb b4smb
ren _b_hml b4hml
ren _b_mom b4mom
keeporder cusip b4*
save b4mkt.dta, replace
*/

***** Estimate betas using 2006-2015 window
use stockmonth_7f, clear
keep if ym>=ym(2006,1) & ym<=ym(2015,12)
statsby _b _se e(r2) e(N), by(cusip) clear: reg retrf mktrf smb hml mom
keep if _eq2_stat_2>=24
ren _b_mktrf b4mkt0615
ren _b_smb b4smb0615
ren _b_hml b4hml0615
ren _b_mom b4mom0615
keeporder cusip b4*
save b4mkt_0615.dta, replace

***** Estimate betas using 2010-2018 window
use stockmonth_7f, clear
keep if ym>=ym(2010,1) & ym<=ym(2018,12)
statsby _b _se e(r2) e(N), by(cusip) clear: reg retrf mktrf smb hml mom
keep if _eq2_stat_2>=24
ren _b_mktrf b4mkt1018
ren _b_smb b4smb1018
ren _b_hml b4hml1018
ren _b_mom b4mom1018
keeporder cusip b4*
save b4mkt_1018.dta, replace

* firm names, fixed for each cusip
use "../Data/CRSP Stock/firmnames_2023.dta", clear
ren *, lower
gen tmp=-date
sort cusip tmp
by cusip: gen fob=(_n==1)
keep if fob==1
keep cusip comnam
save firmnames_2023.dta, replace

***************** Calculate stock-level non-TDF-affiliated MF ownership
use "../Data/Thomson Reuters/TRholdings_201803_202206.dta", clear
joinby fundno using mflink2a
gen quarter=qofd(fdate)
collapse (mean)shares, by(wficn cusip quarter)
format quarter %tq
save TRholdings_2022_full.dta, replace


************ (1) Calculate stock-level frac shares held by mutual funds NOT held by TDFs
* assuming TDF ownership in MFs are zero before 2008 (in particular 2001-2005 for calculating the pre-period)
* List of RELEVANT WFICN (equity funds only, ZERO TDF ownership only), obtained from crsp_portno/crsp_fundno
use portno_quarterly_2022, clear
tab broadcat, m
joinby crsp_portno quarter using cusipportno_tdf_ownership_2022, unm(b)
tab _m
keep if _m==1 | _m==3
drop _m
replace fdpct=0 if fdpct==.
keep if fdpct==0
keeporder crsp_portno quarter
save notdfMFlist2022.dta, replace

*** convert crsp_portno to WFICN
use fundq_2018_2022_1, clear
keep crsp_fundno quarter crsp_portno 
joinby crsp_portno quarter using notdfMFlist2022

* add WFICN
joinby crsp_fundno using "C:\Users\Yang Sun\Dropbox\TDF\Data\MFLINK\mflink1_2023"
drop crsp_fundno /* drop share class indicator*/
duplicates drop /* drop obs for different share classes */
duplicates tag crsp_portno quarter, gen(dup)
tab dup
drop if dup!=0 /*0.4% obs*/
drop dup
save portno_wficn_bridge_2022_notdf.dta, replace

* select subsample of MFs with ZERO TDF investments
use notdfMFlist2022, clear
joinby crsp_portno quarter using portno_wficn_bridge_2022_notdf
joinby crsp_portno quarter using portno_index_2022
collapse (max)index, by(wficn quarter)
duplicates drop
save wficnquarter_nonTDF_2022.dta, replace

**** Total shares of each stock owned by non-TDF invested mutual funds
use TRholdings_2022_full, clear
joinby wficn quarter using wficnquarter_nonTDF_2022
collapse (sum)shares, by(cusip index quarter)
reshape wide shares, i(cusip quarter) j(index)
drop if cusip==""
foreach var in shares0 shares1{
replace `var'=0 if `var'==.
}
ren shares0 sharesactmf
ren shares1 sharesindmf
gen sharesmf=sharesactmf+sharesindmf

joinby cusip quarter using stockquarterly_2022, unm(b)

foreach var in actmf indmf mf {
gen `var'pct=shares`var'/(shrout*1000)
}

drop if mfpct>1 /*restricting to _m=3 since mfpct=. for _m=1 or _m=2*/

keeporder cusip quarter mfpct actmfpct indmfpct
sort cusip quarter
foreach var in mfpct actmfpct indmfpct {
    by cusip: gen L`var'=`var'[_n-1] if quarter==quarter[_n-1]+1
}
save stkmfpct_2022.dta, replace


**** Stock illiquidity measure
use "C:\Users\Yang Sun\Dropbox\TDF\Data\CRSP Stock\stockdaily20182022.dta", clear
ren PERMNO permno
ren CUSIP cusip
ren DlyCalDt date
ren DlyPrc prc
ren DlyRet ret
ren DlyVol vol

*** generate delta log price t and delta log price t-1
replace prc=-prc if prc<0
gen lnprice=ln(prc)
sort cusip date
by cusip: gen Llnprice=lnprice[_n-1]
by cusip: gen L2lnprice=lnprice[_n-2]
gen dpt=lnprice-Llnprice
gen Ldpt=Llnprice-L2lnprice
by cusip: gen Lret=ret[_n-1]
save stkdaily_2022.dta, replace

**** Stock-level measure of liquidity
use stkdaily_2022, clear
sort cusip date
by cusip: gen Lprc=prc[_n-1]
replace vol=vol/1000
gen illiq=sqrt(abs(ret)/(vol*Lprc))
gen quarter=qofd(date)
collapse (mean)illiq, by(cusip quarter)
su illiq, d
winsor illiq
su illiq, d
sort cusip quarter
by cusip: gen Lilliq=illiq[_n-1] if quarter==quarter[_n-1]+1
save stock_quarterlyamihud_2022.dta, replace

***************************************************************
***************************************************************
***************************************************************
*** CALCULATE RISK-ADJUSTED RETURNS 

use stockmonth_4f_2023, clear
keep if ym>=ym(2018,1) & ym<=ym(2022,6)

*** add betas based on pre-period 1996-2005
* time invariant
joinby cusip using b4mkt, unm(b)
tab _m
keep if _m==1 | _m==3
drop _m
gen alpha4=retrf-b4mkt*mktrf-b4smb*smb-b4hml*hml-b4mom*mom

*** add betas using fixed 2009-2018 window
joinby cusip using b4mkt_0918, unm(b)
keep if _m==1 | _m==3
drop _m
gen b0918alpha4=retrf-b4mkt0918*mktrf-b4smb0918*smb-b4hml0918*hml-b4mom0918*mom


*** add betas using fixed 2006-2015 window
joinby cusip using b4mkt_0615, unm(b)
keep if _m==1 | _m==3
drop _m
gen b0615alpha4=retrf-b4mkt0615*mktrf-b4smb0615*smb-b4hml0615*hml-b4mom0615*mom

***** time varying, lagged market cap and trading volume
gen marketcap=(prc*shrout)/1000 /* in million$ */
*replace marketcap=marketcap/1000
sort cusip ym
by cusip: gen Lmktcap=marketcap[_n-1] if ym==ym[_n-1]+1
gen lnmktcap=ln(marketcap)
gen lnLmktcap=ln(Lmktcap)

** Normalize trading volume by shares outstanding
by cusip: gen Lvol=vol[_n-1] if ym==ym[_n-1]+1
gen lnLvol=ln(Lvol)
su lnLvol, d

do "../Do files/ffind12.do"
tostring siccd, replace
gen sic3=substr(siccd,1,3)
destring sic3, replace
gen ym_sic3=string(ym)+"_"+string(sic3)
gen ym_ffind12=string(ym)+"_"+string(ffind)
drop _*

joinby cusip quarter using utdfpct_2022, unm(b)
keep if _m==1 | _m==3
drop _m
joinby cusip quarter using stkmfpct_2022, unm(b)
keep if _m==1 | _m==3
drop _m

su Lmfpct Lutdfallpct

joinby ym using benchmarkmonthly2022

gen diffret=bmpfmretdom_eq-bmpfmretfixed_inc
gen Ldiffret=Lbmpfmretdom_eq-Lbmpfmretfixed_inc

foreach var in Lmfpct Lutdfallpct Lutdfpaspct Lutdfactpct Lutdfpctp Lutdfpcta L2utdfallpct {
replace `var'=`var'*100
foreach yy in diffret Ldiffret {
gen `yy'_`var'=`yy'*`var'
}
}

codebook quarter
*bys ym: egen sized=xtile(marketcap),nq(10)
*sort cusip ym
*by cusip: gen Lsized=sized[_n-1] if ym==ym[_n-1]+1
foreach var in diffret Ldiffret {
gen `var'_lnLmktcap=`var'*lnLmktcap
}
joinby cusip quarter using stockquarterly_2022
gen fquarter=quarter
joinby cusip fquarter using divyieldcrsp2022, unm(b)
tab _m
drop if _m==2
drop _m

joinby cusip fquarter using compustat_profinv_quarter_2023, unm(b)
tab _m 
keep if _m==1 | _m==3
drop _m

joinby cusip quarter using stock_quarterlyamihud_2022, unm(b)
tab _m
keep if _m==1 | _m==3
drop _m

bys cusip: egen maxutdfallpct=max(utdfallpct)

keep if lbbreak>1 & lbbreak!=. & Lprc>=5 & Lprc!=.

sort cusip ym
forvalues i=1/12 {
    by cusip: gen L`i'ret=mret[_n-`i'] if ym==ym[_n-`i']+`i'
}

gen Lret2_12=L2ret
forvalues i=3/12{
    replace Lret2_12=Lret2_12+L`i'ret
}

gen Lret2_6=L2ret
forvalues i=3/6{
    replace Lret2_6=Lret2_6+L`i'ret
}


sort cusip ym

forvalues i=1/12{
    foreach var in alpha4 ralpha4 {
	    by cusip: gen F`i'`var'=`var'[_n+`i'] if ym==ym[_n+`i']-`i'
	}
}
drop if maxutdfallpct==0

foreach var in diffret Ldiffret{
    gen `var'_lnLvol=`var'*lnLvol
}
save stockmonthly_2022_forreg2.dta, replace

