cd "C:\Users\Yang Sun\Dropbox\TDF\Output"

*** Define programs
set more off 
cap prog drop _all
program define winsor

sum `1', d
replace `1'=r(p1) if `1'<r(p1) & `1'!=.
replace `1'=r(p99) if `1'>r(p99) &`1'!=. 
end
program define clean
sum `1',d
replace `1' = r(p50)-5*(r(p75)-r(p25)) if `1'<(r(p50)-5*(r(p75)-r(p25)))&`1'~=.
replace `1' = r(p50)+5*(r(p75)-r(p25)) if `1'>(r(p50)+5*(r(p75)-r(p25)))&`1'~=.
end
program define winsor5
sum `1', d
replace `1'=r(p5) if `1'<r(p5) & `1'!=.
replace `1'=r(p95) if `1'>r(p95) &`1'!=. 
end
program define trim
sum `1', d
replace `1'=. if `1'<r(p1) & `1'!=.
replace `1'=. if `1'>r(p99) &`1'!=. 
end


*******************************************
**** Table 3 Summary Statistics
*** TDF level
use portno_quarterly_2022, clear
* Add indicators for active vs passive TDFs
joinby crsp_portno quarter using tdfactpas2022, unm(b)
tab _m 
keep if _m==3
drop _m

joinby crsp_portno using portno_series_2022, unm(b)
tab _m
keep if _m==1 | _m==3
drop _m

joinby series_name1 quarter using passiveseries2022, unm(b)
tab _m
keep if _m==1 | _m==3
drop _m

label var tgyr "Target year"
label var per_cash "Cash"

drop if passiveseries==.
gen ytor=tgyr-yofd(dofq(quarter))
su ytor, d

foreach var in fdtna seriessize {
	replace `var'=`var'/1000
}
replace wqret=wqret*100

foreach var in fdtna tgyr ytor wqret seriessize passiveseries {
	drop if `var'==.
}

keep if quarter>=yq(2019,1) & quarter<=yq(2022,4)
duplicates report crsp_portno quarter

replace per_cash=per_cash*100

eststo clear
estpost summarize fdtna tgyr ytor wqret per_cash seriessize passiveseries, detail
estout using "summstat_tdf2022.xls", cells("count mean(fmt(3)) p25(fmt(3)) p50(fmt(3)) p75(fmt(3)) sd(fmt(3))") replace

** Summary statistics MF monthly
use monthlydata_portno_forreg_2019, clear
append using monthlydata_portno_forreg_new
sort crsp_portno ym
keep if ym>=ym(2019,1) & ym<=ym(2022,12)
* exp ratio is all missing in 2022Q4
by crsp_portno: replace wexp_ratio=wexp_ratio[_n-1] if wexp_ratio==. & wexp_ratio[_n-1]!=.

drop if broadcat=="mixed"
gen diffret_index=diffret*index
gen Ldiffret_index=Ldiffret*index

sum mflowpct if broadcat=="dom_eq", d
replace mflowpct=. if mflowpct<r(p1) & mflowpct!=.
replace mflowpct=. if mflowpct>r(p99) & mflowpct!=. 

sum mflowpct if broadcat=="for_eq", d
replace mflowpct=. if mflowpct<r(p1) & mflowpct!=.
replace mflowpct=. if mflowpct>r(p99) & mflowpct!=. 

sort crsp_portno ym
by crsp_portno: egen maxtdfallpctt=max(tdfallpct)

drop if maxtdfallpct==0

replace fdtna=fdtna/1000
replace ffsize=ffsize/1000

foreach var in mflowpct wexp_ratio wsd1yr tdfallpct{
	replace `var'=`var'*100
}

foreach var in mflowpct index tdfallpct fdtna ffsize age wexp_ratio wsd1yr diffret{
    drop if `var'==.
}

codebook ym
eststo clear
estpost summarize mflowpct index tdfallpct fdtna ffsize age wexp_ratio wsd1yr diffret  if broadcat=="dom_eq", detail
estout using "summstat_MF_2022.xls", cells("count mean(fmt(3)) p25(fmt(3)) p50(fmt(3)) p75(fmt(3)) sd(fmt(3))") replace


****** Summ stats stock monthly
use stockmonthly_2022_forreg2, clear
codebook ym
keep if ym>=ym(2019,1) & ym<=ym(2022,6)

foreach var in mret alpha4 utdfallpct mfpct ttmdivyieldcrsp roeq investment Lret2_6 {
	replace `var'=`var'*100
}
replace marketcap=marketcap/1000

foreach var in mret alpha4 utdfallpct mfpct marketcap vol mtob ttmdivyieldcrsp roeq investment illiq {
    drop if `var'==.
}
replace illiq=illiq*sqrt(1000)
eststo clear
estpost summarize mret alpha4 utdfallpct mfpct marketcap vol mtob ttmdivyieldcrsp roeq investment illiq, detail
estout using "summstat_stocks_2022.xls", cells("count mean(fmt(3)) p25(fmt(3)) p50(fmt(3)) p75(fmt(3)) sd(fmt(3))") replace



*********************************************************
******************* Table 5

use monthlydata_portno_forreg_2022, clear
keep if ym>=ym(2019,1) 
save monthlydata_portno_forreg_new, replace


use monthlydata_portno_forreg_2019, clear
append using monthlydata_portno_forreg_new
sort crsp_portno ym

keep if ym>=ym(2019,1) & ym<=ym(2022,12)

*** exp ratio is all missing in 2022Q4
by crsp_portno: replace wexp_ratio=wexp_ratio[_n-1] if wexp_ratio==. & wexp_ratio[_n-1]!=.

drop if broadcat=="mixed"
gen diffret_index=diffret*index
gen Ldiffret_index=Ldiffret*index

sum mflowpct if broadcat=="dom_eq", d
replace mflowpct=. if mflowpct<r(p1) & mflowpct!=.
replace mflowpct=. if mflowpct>r(p99) & mflowpct!=. 

sum mflowpct if broadcat=="for_eq", d
replace mflowpct=. if mflowpct<r(p1) & mflowpct!=.
replace mflowpct=. if mflowpct>r(p99) & mflowpct!=. 

sort crsp_portno ym
by crsp_portno: egen maxtdfallpctt=max(tdfallpct)

drop if maxtdfallpct==0

local coeflist "diffret_Ltdfallpct Ldiffret_Ltdfallpct diffret Ldiffret diffret_index Ldiffret_index Ltdfallpct lnLfdtna lnLffsize lnage wexp_ratio Lwsd1yr Lmflowpct"

gen n=1
xi: reghdfe mflowpct diffret_Ltdfallpct diffret diffret_index Ldiffret_Ltdfallpct Ldiffret Ldiffret_index Ltdfallpct lnLfdtna lnLffsize lnage wexp_ratio Lwsd1yr  if broadcat=="dom_eq", a(n) cluster(crsp_portno ym)
outreg2 using flow_NEW_23.xls, replace e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')

xi: reghdfe mflowpct diffret_Ltdfallpct diffret diffret_index Ldiffret_Ltdfallpct Ldiffret Ldiffret_index Ltdfallpct lnLfdtna lnLffsize lnage wexp_ratio Lwsd1yr  if broadcat=="dom_eq", a(crsp_portno) cluster(crsp_portno ym)
outreg2 using flow_NEW_23.xls, e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')

xi: reghdfe mflowpct diffret_Ltdfallpct diffret diffret_index Ldiffret_Ltdfallpct Ldiffret Ldiffret_index Ltdfallpct lnLfdtna lnLffsize lnage wexp_ratio Lwsd1yr if index==1 & broadcat=="dom_eq", a(crsp_portno) cluster(crsp_portno ym)
outreg2 using flow_NEW_23.xls, e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')

xi: reghdfe mflowpct diffret_Ltdfallpct diffret diffret_index Ldiffret_Ltdfallpct Ldiffret Ldiffret_index Ltdfallpct lnLfdtna lnLffsize lnage wexp_ratio Lwsd1yr if index==0 & broadcat=="dom_eq", a(crsp_portno) cluster(crsp_portno ym)
outreg2 using flow_NEW_23.xls, e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')

keep if broadcat=="fixed_inc" & (lipper_class=="A" | lipper_class=="BBB" | lipper_class=="HY" | lipper_class=="SII" | lipper_class=="SID" | lipper_class=="IID" | substr(crsp_obj_cd,1,2)=="IC" | lipper_class=="GUT" | lipper_class=="GUS" | lipper_class=="SUT" | lipper_class=="SUS" | lipper_class=="IUG" | lipper_class=="SIU") | substr(crsp_obj_cd,1,2)=="IU"

gen subcat="C" if lipper_class=="A" | lipper_class=="BBB" | lipper_class=="HY" | lipper_class=="SII" | lipper_class=="SID" | lipper_class=="IID" | substr(crsp_obj_cd,1,2)=="IC"
replace subcat="G" if lipper_class=="GUT" | lipper_class=="GUS" | lipper_class=="SUT" | lipper_class=="SUS" | lipper_class=="IUG" | lipper_class=="SIU" | substr(crsp_obj_cd,1,2)=="IU"

sum mflowpct if subcat=="C", d
replace mflowpct=. if mflowpct<r(p1) & mflowpct!=.
replace mflowpct=. if mflowpct>r(p99) & mflowpct!=. 

xi: reghdfe mflowpct diffret_Ltdfallpct diffret diffret_index Ldiffret_Ltdfallpct Ldiffret Ldiffret_index Ltdfallpct lnLfdtna lnLffsize lnage wexp_ratio Lwsd1yr if subcat=="C" , a(n) cluster(crsp_portno ym)
outreg2 using flow_NEW_23.xls, e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')

xi: reghdfe mflowpct diffret_Ltdfallpct diffret diffret_index Ldiffret_Ltdfallpct Ldiffret Ldiffret_index Ltdfallpct lnLfdtna lnLffsize lnage wexp_ratio Lwsd1yr if subcat=="C" , a(crsp_portno) cluster(crsp_portno ym)
outreg2 using flow_NEW_23.xls, e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')

xi: reghdfe mflowpct diffret_Ltdfallpct diffret diffret_index Ldiffret_Ltdfallpct Ldiffret Ldiffret_index Ltdfallpct lnLfdtna lnLffsize lnage wexp_ratio Lwsd1yr if index==1 & subcat=="C", a(crsp_portno) cluster(crsp_portno ym)
outreg2 using flow_NEW_23.xls, e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')

xi: reghdfe mflowpct diffret_Ltdfallpct diffret diffret_index Ldiffret_Ltdfallpct Ldiffret Ldiffret_index Ltdfallpct lnLfdtna lnLffsize lnage wexp_ratio Lwsd1yr if index==0 & subcat=="C", a(crsp_portno) cluster(crsp_portno ym)
outreg2 using flow_NEW_23.xls, e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')


****************************************
************* Figure 5
******* Plot of market levels 2020 to 2022
use benchmarkmonthly2019, clear
keep if ym<ym(2018,1)
append using benchmarkmonthly2022

ren bmpfmretdom_eq re
ren bmpfmretfixed_inc rb
gen rdif=re-rb
gen Lrdif=rdif[_n-1] if ym==ym[_n-1]+1

label var rdif "RE-RB"
twoway (histogram rdif if ym>=ym(2015,1) & ym<=ym(2018,12),  graphregion(color(white)) bgcolor(white) color(red%30)) (histogram rdif if ym>=ym(2019,1) & ym<=ym(2022,12), color(green%30)), legend(order(1 "2015-2018" 2 "2019-2022" ))
gr export "../Writing/diffret_dist.png", replace	   
	   
label var re "RE"	   
twoway (histogram re if ym>=ym(2015,1) & ym<=ym(2018,12), graphregion(color(white)) bgcolor(white) color(red%30)) (histogram re if ym>=ym(2019,1) & ym<=ym(2022,12), color(green%30)), legend(order(1 "2015-2018" 2 "2019-2022" ))
gr export "../Writing/re_dist.png", replace	   

keep if ym>=ym(2018,12)
foreach var in re rb rdif{
    gen ln`var'1=ln(`var'+1)
	replace ln`var'1=0 if ym==ym(2018,12)
	replace ln`var'1=sum(ln`var'1)
	gen `var'level=exp(ln`var'1)
}

keeporder ym re rb rdif Lrdif relevel rblevel rdiflevel

label var relevel "Equity"
label var rblevel "Bond"
label var rdiflevel "Equity-Bond"

line relevel rdiflevel ym, lcolor(navy*.8 green*.5) lpattern(solid dash) graphregion(color(white)) bgcolor(white) ytitle("RE and RE-RB Performance") xtitle("Year-Month") 
*note("Normalized to 1 at beginning 2009.01")
gr export "../Writing/totalmkt_level.png", replace

line rdiflevel ym, lcolor(navy*.6) graphregion(color(white)) bgcolor(white) ytitle("RE-RB Performance") xtitle("Year-Month") 
gr export "../Writing/difret_level.png", replace

l ym rdif Lrdif if abs(rdif)>.08 & ym>=ym(2019,1)


*****************************************
********** Table 4 Contrast fund flows to high-TDF and low-TDF funds
use monthlydata_portno_forreg_2019, clear
append using monthlydata_portno_forreg_new
sort crsp_portno ym
keep if ym>=ym(2018,1) & ym<=ym(2022,12)
* keep domestic equity funds
gen kp=1 if broadcat=="dom_eq"
sort crsp_portno ym
by crsp_portno: egen keep=sum(kp)
drop if keep==0
drop kp keep
save tmp_domeqfds.dta, replace

*** take the average TDF ownership during 2018 (4-quarter average) and sort funds
use tmp_domeqfds, clear
keep if ym==ym(2018,3) | ym==ym(2018,6) | ym==ym(2018,9) | ym==ym(2018,12)
collapse (mean)tdfallpct, by(crsp_portno)
egen mdtdfallpct=median(tdfallpct) if tdfallpct!=0
gen tdfgroup=2 if tdfallpct>mdtdfallpct
replace tdfgroup=1 if tdfallpct<=mdtdfallpct & tdfallpct!=0
replace tdfgroup=0 if tdfallpct==0
save tdffunds_sort.dta, replace

use tdffunds_sort, clear
tab tdfgroup, sum(tdfallpct)

use tmp_domeqfds, clear
joinby crsp_portno using tdffunds_sort
sort crsp_portno ym
by crsp_portno: gen Fmflow=mflow[_n+1] if ym==ym[_n+1]-1
gen m2flowpct=(mflow+Fmflow)/Lfdtna
su mflowpct, d
replace mflowpct=. if mflowpct<r(p1) & mflowpct!=.
replace mflowpct=. if mflowpct>r(p99) & mflowpct!=. 

***  Keep high vol months
keep if ym==ym(2019,5) | ym==ym(2020,2) | ym==ym(2020,3) | ym==ym(2020,4) | ym==ym(2020,8) | ym==ym(2020,11) | ym==ym(2022,10)

keep crsp_portno ym tdfgroup mflowpct 

replace mflowpct=mflowpct*100
reshape wide mflowpct, i(crsp_portno tdfgroup) j(ym)

eststo clear
estpost summarize mflowpct* if tdfgroup==2, detail
estout using "fdflow_H.xls", cells("count mean(fmt(3)) p25(fmt(3)) p50(fmt(3)) p75(fmt(3)) sd(fmt(3))") replace
eststo clear
estpost summarize mflowpct* if tdfgroup==1, detail
estout using "fdflow_L.xls", cells("count mean(fmt(3)) p25(fmt(3)) p50(fmt(3)) p75(fmt(3)) sd(fmt(3))") replace
eststo clear
estpost summarize mflowpct* if tdfgroup==0, detail
estout using "fdflow_0.xls", cells("count mean(fmt(3)) p25(fmt(3)) p50(fmt(3)) p75(fmt(3)) sd(fmt(3))") replace

gen tmpgrp=3-tdfgroup
foreach i in 712 721 722 723 727 730 753 {
    ttest mflowpct`i' if tmpgrp==1 | tmpgrp==2, by(tmpgrp)
}




********** Generate aggregate dataset 
****** Longer time series starting in 2000
** aggregate from share class to fund level

use monthlydata2022, clear
codebook ym
keep if ym>=ym(2019,1)
save monthlydata2022_temp.dta, replace

use monthlydata, clear 
keep if ym<=ym(2018,12)

append using monthlydata2022_temp

sort crsp_portno ym
foreach var of varlist sd1yr exp_ratio mret {
gen w=`var'*Lmtna
egen ww=sum(w) if w<., by(crsp_portno ym)
egen www=median(ww), by(crsp_portno ym)
egen t=sum(Lmtna) if w<., by(crsp_portno ym)
egen tt=median(t), by(crsp_portno ym)
gen w`var'=www/tt
replace w`var'=. if w`var'==0
drop w ww www t tt
}
* institutional indicator
bys crsp_portno ym ins: egen tmpsum=sum(mtna)
gen tmpsum0=tmpsum if ins==0
gen tmpsum1=tmpsum if ins==1
by crsp_portno ym: egen retsize=median(tmpsum0)
by crsp_portno ym: egen inssize=median(tmpsum1)
by crsp_portno ym: egen totsize=sum(mtna)
replace retsize=0 if retsize==.
replace inssize=0 if inssize==.
gen insshr=inssize/totsize
* collapse to fund level
collapse (mean)wmret (sum)fdtna=mtna (mean)ffsize (min)inception_month (mean)wexp_ratio (mean)wsd1yr (mean)insshr (mean)index (mean)etf, by(crsp_portno broadcat ym)
duplicates report crsp_portno ym
gen fdins=(ins>0.5)
tab fdins, m

* calculate monthly FUND flow
sort crsp_portno ym
by crsp_portno: gen Lfdtna=fdtna[_n-1] if ym==ym[_n-1]+1
gen mflow=fdtna-Lfdtna*(1+wmret)
gen mflowpct=mflow/Lfdtna
gen lnLfdtna=ln(Lfdtna)

sort crsp_portno ym
by crsp_portno: gen Lffsize=ffsize[_n-1] if ym==ym[_n-1]+1
gen lnLffsize=ln(Lffsize)

gen age=yofd(dofm(ym))-yofd(dofm(inception_month))+1
keep if age>=1
gen lnage=ln(age)

gen quarter=qofd(dofm(ym))
format quarter %tq
codebook ym
save MF_longmonthly.dta, replace


**** Long time series of asset class returns
use benchmarkmonthly2022, clear
keep if ym>=ym(2020,1) & ym<=ym(2022,12)
append using "C:\Users\Yang Sun\Dropbox\Typos\Output\benchmarkmonthly_long.dta"
sort ym
save benchmarkmonthly_longtemp.dta, replace

**** Calculate aggregate flows to each asset class
use MF_longmonthly, clear
** keep only funds that are classified as domestic equity at some point during sample
gen kp=1 if broadcat=="dom_eq"
bys crsp_portno: egen keep=sum(kp)
drop if keep==0
drop keep kp

** to calculate weighted-average aggregate returns
gen wwmret=fdtna*wmret

*** treat the outliers as data errors, drop before aggregating
/*forvalues i=480/755{
su mflowpct if ym==`i', d
replace mflow=. if ym==`i' & mflowpct<r(p1) & mflowpct!=.
replace mflow=. if ym==`i' & mflowpct>r(p99) & mflowpct!=. 
}*/
drop if (mflowpct>2 & mflowpct!=.) | mflowpct<-.5

** two ways of aggregating (1) summing up dollar flow of each fund (2) calculating aggregate flow using weighted-average aggregate returns

collapse (sum)mflow (sum)fdtna (sum)wwmret, by(ym)
replace wwmret=wwmret/fdtna

sort ym

* (2) method: aggregate flow calculated using aggregate assets and returns
gen Lfdtna=fdtna[_n-1] if ym==ym[_n-1]+1
gen aggflow=fdtna-Lfdtna*(1+wwmret)

gen L3fdtna=fdtna[_n-3] if ym==ym[_n-3]+3
gen L6fdtna=fdtna[_n-6] if ym==ym[_n-6]+6
gen L12fdtna=fdtna[_n-12] if ym==ym[_n-12]+12

joinby ym using benchmarkmonthly_longtemp, unm(b)
tab _m
keep if _m==3
drop _m

gen re=bmpfmretdom_eq
gen diffret=bmpfmretdom_eq-bmpfmretfixed_inc

keep ym wwmret fdtna Lfdtna mflow aggflow Lfdtna L3fdtna L6fdtna L12fdtna re diffret

*** smooth dollar flow data
tsset ym
foreach var of varlist mflow aggflow {
    tssmooth ma `var'_ma=`var', window(2 1 0)
}
*** smooth out equity market returns
tssmooth ma re_ma=re, window(2 1 0)

    gen aggflowpct1_ma=mflow_ma/L3fdtna 
    gen aggflowpct2_ma=aggflow_ma/L3fdtna 

label var aggflowpct1 "Agg. Flow to Domestic Equity Funds" /*aggregate fund flow summed up from invidual funds, smoothed over m-2 to m, normalized by TNA m-3*/
label var aggflowpct2 "Agg. Flow to Domestic Equity Funds" /*aggregate fund flow calculated from agg assets, smoothed over m-2 to m, normalized by TNA m-3*/

label var re_ma "Equity Market Return"

foreach var in aggflowpct1 aggflowpct2 {
    replace `var'=`var'*100
}
replace re_ma=re_ma*100 

keep if ym>=ym(2007,1)
su ym if ym==ym(2008,1)
su ym if ym==ym(2011,12)
su ym if ym==ym(2019,1)
su ym if ym==ym(2022,12)
save graphtemp.dta, replace

*****************************************************************
*************** Figure 2
use graphtemp, clear
keep if ym>=ym(2008,1) & ym<=ym(2011,12)
su ym
corr aggflowpct1 re_ma
return list
local rho = floor(r(rho)*100)/100
twoway (line aggflowpct1 ym, text(3.5 610 "Correlation=`rho'", place(e) color(maroon)) xtitle("Year-Month") graphregion(color(white)) bgcolor(white) xlabel(576(6)623, labsize(small)) ylabel(-4(2)4, labsize(small)) legend(size(small)))(bar re_ma ym, yaxis(2) ylabel(-12(6)12, axis(2) labsize(small)) color(green%30) legend(order(1 "Agg.Flow to Domestic Equity Funds %" 2 "Equity Market Return %") size(small)))
gr export "aggpflowdom_eq_0710.png", replace

use graphtemp, clear
keep if ym>=ym(2019,1) & ym<=ym(2022,12)
su ym
corr aggflowpct1 re_ma
return list
local rho = floor(r(rho)*100)/100
twoway (line aggflowpct1 ym, text(3.5 742 "Correlation=`rho'", place(e) color(maroon)) xtitle("Year-Month") graphregion(color(white)) bgcolor(white) xlabel(708(6)755, labsize(small)) ylabel(-4(2)4, labsize(small)) legend(size(small)))(bar re_ma ym, yaxis(2) ylabel(-12(6)12, axis(2) labsize(small)) color(green%30) legend(order(1 "Agg.Flow to Domestic Equity Funds %" 2 "Equity Market Return %") size(small)))
gr export "aggpflowdom_eq_1922.png", replace

*****************************************************************
****************** Table 6
********* Stock returns
use stockmonthly_2022_forreg2, clear
codebook ym
keep if ym>=ym(2019,1) & ym<=ym(2022,6)
gen sic3_ym=string(sic3)+"_"+string(ym)

su alpha4, d

*** Other controls
gen lnLmtob=ln(Lmtob)
su Lttmdivyieldcrsp Lroeq Linvestmentq Lilliq

foreach var in lnLmtob Lttmdivyieldcrsp Lroeq Linvestmentq Lilliq {
	gen diffret_`var'=diffret*`var'
	gen Ldiffret_`var'=Ldiffret*`var'
}

local coeflist "diffret_Lutdfallpct Ldiffret_Lutdfallpct Lutdfallpct L1ret Lret2_6"

*** Fixed pre-window for beta calculation
* (1) no controls
xi: reghdfe alpha4 diffret_Lutdfallpct Ldiffret_Lutdfallpct Lutdfallpct, a(sic3_ym) cluster(ym cusip)
outreg2 using stkret_jpef.xls, replace e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')

xi: reghdfe alpha4 diffret_Lutdfallpct Ldiffret_Lutdfallpct Lutdfallpct Lmfpct lnLmktcap lnLvol lnLmtob Lttmdivyieldcrsp Lroeq Linvestmentq Lilliq, a(sic3_ym) cluster(ym cusip)
outreg2 using stkret_jpef.xls, e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')

xi: reghdfe alpha4 diffret_Lutdfallpct Ldiffret_Lutdfallpct Lutdfallpct Lmfpct lnLmktcap lnLvol lnLmtob Lttmdivyieldcrsp Lroeq Linvestmentq Lilliq L1ret Lret2_6, a(sic3_ym) cluster(ym cusip)
outreg2 using stkret_jpef.xls, e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')

xi: reghdfe alpha4 diffret_Lutdfallpct Ldiffret_Lutdfallpct Lutdfallpct Lmfpct lnLmktcap lnLvol lnLmtob Lttmdivyieldcrsp Lroeq Linvestmentq Lilliq diffret_Lmfpct Ldiffret_Lmfpct diffret_lnLmktcap Ldiffret_lnLmktcap diffret_lnLvol Ldiffret_lnLvol diffret_lnLmtob Ldiffret_lnLmtob diffret_Lttmdivyieldcrsp Ldiffret_Lttmdivyieldcrsp diffret_Lroeq Ldiffret_Lroeq diffret_Linvestmentq Ldiffret_Linvestmentq diffret_Lilliq Ldiffret_Lilliq, a(sic3_ym) cluster(ym cusip)
outreg2 using stkret_jpef.xls, e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')

xi: reghdfe alpha4 diffret_Lutdfallpct Ldiffret_Lutdfallpct Lutdfallpct Lmfpct lnLmktcap lnLvol lnLmtob Lttmdivyieldcrsp Lroeq Linvestmentq Lilliq diffret_Lmfpct Ldiffret_Lmfpct diffret_lnLmktcap Ldiffret_lnLmktcap diffret_lnLvol Ldiffret_lnLvol diffret_lnLmtob Ldiffret_lnLmtob diffret_Lttmdivyieldcrsp Ldiffret_Lttmdivyieldcrsp diffret_Lroeq Ldiffret_Lroeq diffret_Linvestmentq Ldiffret_Linvestmentq diffret_Lilliq Ldiffret_Lilliq L1ret Lret2_6, a(sic3_ym) cluster(ym cusip)
outreg2 using stkret_jpef.xls, e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')


winsor b0615alpha4
winsor b1019alpha4
winsor b1018alpha4
winsor b0918alpha4

xi: reghdfe b0615alpha4 diffret_Lutdfallpct Ldiffret_Lutdfallpct Lutdfallpct, a(sic3_ym) cluster(ym cusip)
outreg2 using stkret_jpef.xls, e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')

xi: reghdfe b0918alpha4 diffret_Lutdfallpct Ldiffret_Lutdfallpct Lutdfallpct, a(sic3_ym) cluster(ym cusip)
outreg2 using stkret_jpef.xls, e(all) excel label bdec(3) keep(`coeflist') sortvar(`coeflist')


***** To show active and passive TDF holdings highly correlated thus cannot be separately estimated
use stockquarterly_2022, clear
joinby cusip quarter using utdfpct_2022
foreach var in utdfactpct utdfpaspct {
	replace `var'=0 if `var'==.
}

corr utdfactpct utdfpaspct

foreach var in utdfpaspct utdfactpct {
bys quarter: egen `var'd=xtile(`var'), nq(10)
}
collapse utdfpaspctd, by(lbbreak utdfactpctd)
label var lbbreak "NYSE breakpoint"
label var utdfactpctd "Active TDF decile"
label var utdfpaspctd "Avg. passive TDF decile" 
surface lbbreak utdfactpctd utdfpaspctd, orient(xyz) nobox wcolor(midblue) xlabel(2(2)20) ylabel(2(2)10) zlabel(2(2)10) graphregion(color(white)) bgcolor(white) 
gr export "../Writing/surface3d_actpas_2022.png", replace



** stock sample
use stockmonthly_2022, clear
gen mktcap=(prc*shrout)/1000
joinby ym using nysesizebreak_2023_longer
gen lbbreak=1 if mktcap<=b1
forvalues i=2/20 {
local j=`i'-1
replace lbbreak=`i' if mktcap>b`j' & mktcap<=b`i'
}
replace lbbreak=20 if lbbreak==. & mktcap!=.
tab lbbreak
*** drop smallest stocks and penny stocks
keep if lbbreak>1 & lbbreak!=. & Lprc>=5 & Lprc!=.
keep if ym==ym(2018,3) | ym==ym(2018,6) | ym==ym(2018,9) | ym==ym(2018,12)
keeporder cusip quarter lbbreak mktcap
duplicates report cusip quarter
save tmpselect.dta, replace


**** TDF ownership as average during 2018
use utdfpct_2022, clear
keep if quarter>=yq(2018,1) & quarter<=yq(2018,4)
collapse (mean)utdfallpct, by(cusip)
ren utdfallpct utdfallpct0
save stktdfpct0.dta, replace

*** sort sample stoocks in 2018 according to TDF ownership
use utdfpct_2022, clear
keep if quarter>=yq(2018,1) & quarter<=yq(2018,4)
joinby cusip quarter using tmpselect
collapse (min)lbbreak (mean)mktcap (mean)utdfallpct, by(cusip)
drop if utdfallpct==.
egen tdfq00=xtile(utdfallpct), nq(5)
keeporder cusip tdfq00
save stksort_2018.dta, replace

******************
***** Summary stats of betas by TDF ownerhsip quintiles
use stksort_2018, clear
joinby cusip using b4mkt_0918, unm(b)
keep if _m==1 | _m==3
drop _m
joinby cusip using b4mkt_0615, unm(b)
keep if _m==1 | _m==3
drop _m
joinby cusip using b4mkt, unm(b)
keep if _m==1 | _m==3
drop _m

foreach var in b4mkt0918 b4mkt0615 b4mkt {
	gen mis`var'=missing(`var')
}

forvalues i=1/5{
eststo clear
estpost summarize b4mkt0918 b4mkt0615 b4mkt if tdfq00==`i', detail
estout using "betasumm_`i'.xls", cells("count mean(fmt(3)) p25(fmt(3)) p50(fmt(3)) p75(fmt(3)) sd(fmt(3))") replace
}

su misb4mkt0918 misb4mkt0615 misb4mkt if tdfq00==5
su misb4mkt0918 misb4mkt0615 misb4mkt if tdfq00==4
su misb4mkt0918 misb4mkt0615 misb4mkt if tdfq00==3
su misb4mkt0918 misb4mkt0615 misb4mkt if tdfq00==2
su misb4mkt0918 misb4mkt0615 misb4mkt if tdfq00==1

eststo clear
estpost summarize mflowpct* if tdfgroup==1, detail
estout using "fdflow_L.xls", cells("count mean(fmt(3)) p25(fmt(3)) p50(fmt(3)) p75(fmt(3)) sd(fmt(3))") replace
eststo clear
estpost summarize mflowpct* if tdfgroup==0, detail
estout using "fdflow_0.xls", cells("count mean(fmt(3)) p25(fmt(3)) p50(fmt(3)) p75(fmt(3)) sd(fmt(3))") replace



****************************************************************
*********** Collapsed cross section of stocks
**** Average mutual fund ownership during 2018
use stkmfpct_2022, clear
keep if quarter>=yq(2018,1) & quarter<=yq(2018,4)
collapse (mean)mfpct, by(cusip)
ren mfpct mfpct0
save stkmfpct0.dta, replace

*** Ex ante measure of market cap and volume
use stockmonthly_2022, clear
keep if ym>=ym(2018,1) & ym<=ym(2018,12)
gen mktcap=(prc*shrout)/1000 /*in millions*/
collapse (mean)mktcap (mean)vol, by(cusip)
ren mktcap mktcap0
ren vol vol0
save mcvol0.dta, replace

*** Ex ante other controls
use stockmonthly_2022_forreg2, clear
keep if ym==ym(2018,3) | ym==ym(2018,6) | ym==ym(2018,9) | ym==ym(2018,12)
collapse mtob ttmdivyieldcrsp roeq investmentq illiq, by(cusip)
foreach var in mtob ttmdivyieldcrsp roeq investmentq illiq {
	ren `var' `var'0
}
gen lnmtob0=ln(mtob0)
save othcontrols.dta, replace

*** Average mktcap and vol during sample period
use stockmonthly_2022, clear
keep if ym>=ym(2019,1) & ym<=ym(2022,12)
* sample restriction
gen mktcap=(prc*shrout)/1000
joinby ym using nysesizebreak_2023_longer
gen lbbreak=1 if mktcap<=b1
forvalues i=2/20 {
local j=`i'-1
replace lbbreak=`i' if mktcap>b`j' & mktcap<=b`i'
}
replace lbbreak=20 if lbbreak==. & mktcap!=.
tab lbbreak

*** drop smallest stocks and penny stocks
keep if lbbreak>1 & lbbreak!=. & Lprc>=5 & Lprc!=.

* generate a copy of mret which drops outliers
gen mret1=mret
winsor mret1
su mret1, d
drop if mret1==.
gen extremeret=(abs(mret1)>.1)

collapse (sd)sdmret=mret (sd)sdmret1=mret1 (mean)extremeret (mean)mktcap (mean)vol (count)count=mret1, by(cusip)

su count, d
keep if count>=24

* add average tdf ownership in 2018
joinby cusip using stktdfpct0, unm(b)
keep if _m==1 | _m==3
drop _m

* add average mf ownership in 2018
joinby cusip using stkmfpct0, unm(b)
keep if _m==1 | _m==3
drop _m

* add tdf quintile in 2018
joinby cusip using stksort_2018, unm(b)
keep if _m==1 | _m==3
drop _m

joinby cusip using mcvol0, unm(b)
keep if _m==1 | _m==3
drop _m
joinby  cusip using othcontrols, unm(b)
keep if _m==1 | _m==3
drop _m

tab tdfq, su(sdmret)
tab tdfq, su(sdmret1)

foreach var in mktcap vol mktcap0 vol0 {
	gen ln`var'=ln(`var')
}
save collapsexsec_stocks_forreg.dta, replace

use collapsexsec_stocks_forreg, clear
foreach var in sdmret1 extremeret utdfallpct0 mfpct0 ttmdivyieldcrsp0 roeq0 investmentq0 {
    replace `var'=`var'*100
}
replace mktcap0=mktcap0/1000

foreach var in sdmret1 extremeret utdfallpct0 mfpct0 extremeret {
    drop if `var'==.
}
eststo clear
estpost summarize sdmret1 extremeret utdfallpct0 mfpct0 mktcap0 vol0 mtob0 ttmdivyieldcrsp0 roeq0 investmentq0 illiq0, detail
estout using "summstat_xsec2022.xls", cells("count mean(fmt(3)) p25(fmt(3)) p50(fmt(3)) p75(fmt(3)) sd(fmt(3))") replace


*********************************************************
****************** Table 7

reg sdmret1 utdfallpct0, r
outreg2 using collapsexsec_stocks.xls, replace e(all) excel label bdec(3) 

reg sdmret1 utdfallpct0 mfpct0, r
outreg2 using collapsexsec_stocks.xls, e(all) excel label bdec(3) 

reg sdmret1 utdfallpct0 mfpct0 lnmktcap0 lnvol0 lnmtob0 ttmdivyieldcrsp0 roeq0 investmentq0 illiq0, r
outreg2 using collapsexsec_stocks.xls, e(all) excel label bdec(3) 

reg extremeret utdfallpct0, r
outreg2 using collapsexsec_stocks.xls, e(all) excel label bdec(3) 

reg extremeret utdfallpct0 mfpct0, r
outreg2 using collapsexsec_stocks.xls, e(all) excel label bdec(3) 

reg extremeret utdfallpct0 mfpct0 lnmktcap0 lnvol0 lnmtob0 ttmdivyieldcrsp0 roeq0 investmentq0 illiq0, r
outreg2 using collapsexsec_stocks.xls, e(all) excel label bdec(3) 




*********************************************************
****************** Figure 3
*** take residual
use collapsexsec_stocks_forreg, clear

reg sdmret1 mfpct0 lnmktcap0 lnvol0 lnmtob0 ttmdivyieldcrsp0 roeq0 investmentq0 illiq0, r
predict resid_sdmret1, residuals

reg extremeret mfpct0 lnmktcap0 lnvol0 lnmtob0 ttmdivyieldcrsp0 roeq0 investmentq0 illiq0, r
predict resid_extremeret, residuals

collapse (mean)sdmret1 (mean)resid_sdmret1 (mean)extremeret (mean)resid_extremeret, by(tdfq00)

*graph bar resid_sdmret1 , over(tdfq00) 
*graph bar resid_extremeret, over(tdfq00)


label var sdmret1 "Raw Return Volatility"
label var extremeret "Likelihood of Extreme Returns"

graph bar sdmret1 , over(tdfq00) ytitle("Average Volatility") graphregion(color(white)) bgcolor(white) b1title("TDF Quintile")
gr export "../Writing/sdmret_tdf.png", replace

graph bar extremeret , over(tdfq00) ytitle("Likelihood of Extreme Return") graphregion(color(white)) bgcolor(white) b1title("TDF Quintile")
gr export "../Writing/extrret_tdf.png", replace


************************************************************
********************** Figure 6
***** Contruct trading strategy
use stockmonthly_2022, clear
* sample restriction
gen mktcap=(prc*shrout)/1000
joinby ym using nysesizebreak_2023_longer
gen lbbreak=1 if mktcap<=b1
forvalues i=2/20 {
local j=`i'-1
replace lbbreak=`i' if mktcap>b`j' & mktcap<=b`i'
}
replace lbbreak=20 if lbbreak==. & mktcap!=.
tab lbbreak

*** drop smallest stocks and penny stocks
keep if lbbreak>1 & lbbreak!=. & Lprc>=5 & Lprc!=.

*** add factor returns
joinby ym using ff4_monthly_202301
su ret mktrf smb hml mom 
gen retrf=ret-rf
drop if ret==.
* add betas based on pre-period 1996-2005
joinby cusip using b4mkt, unm(b)
tab _m
keep if _m==1 | _m==3
drop _m
gen alpha4=retrf-b4mkt*mktrf-b4smb*smb-b4hml*hml-b4mom*mom

drop if alpha4==.
keep if ym>=ym(2018,12) & ym<=ym(2022,12)
joinby cusip using stksort_2018

gen n=1
bys ym tdfq: egen countc=sum(n)

gen wtmret=mktcap*mret
gen wtalpha4=mktcap*alpha4

joinby ym using benchmarkmonthly2022
gen diffret=bmpfmretdom_eq-bmpfmretfixed_inc
gen Ldiffret=Lbmpfmretdom_eq-Lbmpfmretfixed_inc

collapse (sum)wtmret (mean)mret (sum)wtalpha4  (mean)alpha4 (sum)mktcap (mean)diffret, by(ym tdfq)

foreach var in mret alpha4 {
    replace wt`var'=wt`var'/mktcap
}
drop if tdfq==.

reshape wide wtmret wtalpha4 mret alpha4 mktcap, i(ym) j(tdfq) 

foreach var in mret alpha4 {
    gen wt`var'51=wt`var'5-wt`var'1
	gen `var'51=`var'5-`var'1
}
sort ym
gen Ldiffret=diffret[_n-1] if ym==ym[_n-1]+1
gen L2diffret=diffret[_n-2] if ym==ym[_n-2]+2
gen Lc2diffret=Ldiffret+L2diffret

*** normalize starting point to zero
foreach var in wtmret51 mret51 wtalpha451 alpha451{
	replace `var'=0 if ym==ym(2018,12)
}
save tmp_preport.dta, replace

*** Portfolio returns constructed using contemperaneous returns (infeasible)
use tmp_preport, clear
foreach var in wtmret51 mret51 wtalpha451 alpha451 {
    gen pret`var'=`var' if diffret<0
	replace pret`var'=-`var' if diffret>0
	gen ln`var'1=ln(pret`var'+1)
	replace ln`var'1=sum(ln`var'1)
	gen cumpret`var'=exp(ln`var'1)-1
}

label var cumpretalpha451 "Equal-weighted"
label var cumpretwtalpha451 "Value-weighted"

su ym if ym==ym(2018,12)
su ym if ym==ym(2022,12)
keep if ym>=ym(2018,12)
line cumpretalpha451 ym, xtitle("Year-month") xlabel(707(12)755) ylabel(0(0.1)0.4) clpattern(solid dash) graphregion(color(white)) bgcolor(white)
gr export "../Writing/tradingalpha_t_covid.png", replace


*** Portfolio returns constructed using past returns (feasible)
use tmp_preport, clear
foreach var in wtmret51 mret51 wtalpha451 alpha451 {
    gen pret`var'=`var' if Ldiffret<0
	replace pret`var'=-`var' if Ldiffret>0
	gen ln`var'1=ln(pret`var'+1)
	replace ln`var'1=sum(ln`var'1)
	gen cumpret`var'=exp(ln`var'1)-1
}

label var cumpretalpha451 "Equal-weighted"
label var cumpretwtalpha451 "Value-weighted"

su ym if ym==ym(2018,12)
su ym if ym==ym(2022,12)
keep if ym>=ym(2018,12)
line cumpretalpha451 ym, xtitle("Year-month") xlabel(707(12)755) ylabel(0(0.1)0.4) clpattern(solid dash) graphregion(color(white)) bgcolor(white)
gr export "../Writing/tradingalpha_t-1_covid.png", replace