
*** Start with portno_quarterly_2022 (ending in 2022Q4), combine with previous dataset
use portno_quarterly_2019, clear
keep if quarter<yq(2018,1)
append using portno_quarterly_2022

* Identify BFs
gen balanced=1 if lipper_class=="B" | lipper_class=="MATJ" | lipper_class=="MTAA" | lipper_class=="MTAG" | lipper_class=="MTAM" | lipper_class=="MTAC" | lipper_class=="MTRI"
bys crsp_portno: egen balanced0=max(balanced)
replace balanced0=0 if balanced0==.
replace balanced0=0 if tdf==1
keep if balanced0==1 | tdf==1
replace fdtna=. if fdtna==0
sort crsp_portno quarter
by crsp_portno: replace fdtna=fdtna[_n-1] if fdtna==. & fdtna[_n-1]!=.
drop balanced
save baltdftmp23.dta, replace

***************************************************************************
********************* Aggregate size of TDBFs
use baltdftmp23, clear
collapse (sum)fdtna, by(quarter tdf)
reshape wide fdtna, i(quarter) j(tdf)
label var fdtna0 "Balanced"
label var fdtna1 "Target Date"
* drop problematic quarter with mostly zeros in TNA
replace fdtna0=. if quarter==yq(2017,4)
replace fdtna0=fdtna0[_n-1] if fdtna0==. & fdtna0[_n-1]!=.
*** reduce to yearly
gen qt=quarter(dofq(quarter))
gen year=year(dofq(quarter))
keep if qt==4
drop quarter qt

**** Add assets in CITs - numbers are from Morningstar TDF landscape reports
gen fdtna2=.
replace fdtna2=1325400 if year==2022
replace fdtna2=1470000 if year==2021
replace fdtna2=1204000 if year==2020
replace fdtna2=900000 if year==2019 
replace fdtna2=662400 if year==2018
replace fdtna2=633100 if year==2017 
replace fdtna2=535500 if year==2016
replace fdtna2=454500 if year==2015
replace fdtna2=413600 if year==2014
replace fdtna2=251500 if year==2013
replace fdtna2=135300 if year==2012
replace fdtna2=94500 if year==2011
replace fdtna2=96700 if year==2010
replace fdtna2=59800 if year==2009
replace fdtna2=52000 if year==2008
replace fdtna2=44000 if year==2007
replace fdtna2=17500 if year==2006
replace fdtna2=7100 if year==2005
replace fdtna2=1700 if year==2004
replace fdtna2=1100 if year==2003
replace fdtna2=400 if year==2002
replace fdtna2=300 if year==2001
keep if year>=2001 & year<=2022
gen p1=fdtna1 /*TDF*/
gen p2=p1+fdtna2 /*fdtna2 refers to CITs*/
gen p4=p2+fdtna0 /* fdtna0 refers to BF */
save tdbfsize23.dta, replace

use tdbfsize23, clear
*** in billion dollars
replace p4=p4/1000
replace p2=p2/1000
replace p1=p1/1000

gen citmktshr=fdtna2/(fdtna1+fdtna2)

graph set window fontface "Book Antiqua"
label var p1 "Target date funds"
label var p2 "Target date CITs"
label var p4 "Balanced funds"
keep year p1 p2 p4
save tdbfsize23tmp.dta, replace

twoway area p4 p2 p1 year, title("") xlab(2001(2)2022) xtitle("Year", size(small)) ytitle("$ Billion") legend(row(1) size(small) position(6)) graphregion(color(white)) bgcolor(white) color(ltblue gray dknavy)
gr export "../Writing/TDF_v_BF_size23.png", replace


**** Add total 401k assets invested in mutual funds
import delimited "../Data/DOL/ICI_401k_shares.csv", clear varnames(1)
split date, parse(":")
destring date1, replace
replace date2=subinstr(date2,"Q","",.)
destring date2, replace
replace date2=4 if date2==.
gen quarter=yq(date1,date2)
order quarter
format quarter %tq
drop date date1 
foreach var of varlist domeq_assets-total_assets {
    replace `var'=subinstr(`var',"$","",.)
	replace `var'=subinstr(`var',"%","",.)
	replace `var'=subinstr(`var',",","",.)
	destring `var', replace
}
drop if quarter==.
keep if date2==4
gen year=yofd(dofq(quarter))
joinby year using tdbfsize23, unm(b)
tab _m
keep if _m==3
drop _m
gen tdfshr=((fdtna1*.67)/1000)/total_assets
keep if year>2000
drop p1 p2 p4 
joinby year using tdbfsize23tmp, unm(b)
tab _m
drop _m
graph set window fontface "Book Antiqua"
label var p1 "Target date funds"
label var p2 "Target date CITs"
label var p4 "Balanced funds"
label var tdfshr "Fraction"
twoway (area p4 p2 p1 year, title("") xlab(2001(2)2022) xtitle("Year", size(small)) ytitle("$ Billion") legend(row(2) size(small) position(6) order(1 "Target date funds" 2 "Target date CITs" 3 "Balanced funds" 4 "TDF frac. of 401(k) mutual fund assets")) graphregion(color(white)) bgcolor(white) color(ltblue gray dknavy))(line tdfshr year, yaxis(2) color(green) clpattern(dash))
gr export "../Writing/TDF_v_BF_size23_1.png", replace /*final version*/


line tdfshr year, xline(2005) text(0.3 2005 "Pension Protection Act of 2006", place(e) color(maroon)) graphregion(color(white)) bgcolor(white) ytitle("Fraction") xtitle("Year") note("Source: CRSP and ICI Retirement Market Data")

line tdfshr year, graphregion(color(white)) bgcolor(white) ytitle("Fraction") xtitle("Year") note("Source: CRSP and ICI Retirement Market Data")
gr export "../Writing/401kmf_in_tdf.png", replace


*** Amount of assets by years to retirement

use baltdftmp23, clear
keep if tdf==1
gen ytor=tgyr-yofd(dofq(quarter))
su ytor, d
drop if ytor==.
gen ytorgrp=0 if ytor<=0
replace ytorgrp=1 if ytor>0 & ytor<=10
replace ytorgrp=2 if ytor>10 & ytor<=20
replace ytorgrp=3 if ytor>20 & ytor<=30
replace ytorgrp=4 if ytor>30 & ytor<=40
replace ytorgrp=5 if ytor>40

collapse (sum)fdtna, by(quarter ytorgrp)
reshape wide fdtna, i(quarter) j(ytorgrp)

forvalues i=1/5{
	replace fdtna`i'=0 if fdtna`i'==.
}
*** reduce to yearly
gen qt=quarter(dofq(quarter))
gen year=year(dofq(quarter))
keep if qt==4
drop quarter qt

gen p0=fdtna0 
forvalues i=1/5{
	local j=`i'-1
	gen p`i'=p`j'+fdtna`i'
}

forvalues i=0/5{
	replace p`i'=p`i'/1000
}

label var p0 "<=0"
label var p1 "0-10"
label var p2 "10-20"
label var p3 "20-30"
label var p4 "30-40"
label var p5 ">40"

twoway area p5 p4 p3 p2 p1 p0 year, title("") xlab(2000(2)2022) xtitle("Year") ytitle("$ Billion") legend(row(2) position(6)) graphregion(color(white)) bgcolor(white) scheme(s2color)
gr export "../Writing/TDF_by_years_to_retire.png", replace

***** Amount of assets by target year
use baltdftmp23, clear
keep if tdf==1
drop if tgyr==.

gen tgyr0=.
foreach var in 2000 2010 2020 2030 2040 2050 2060 2070 {
local y=`var'+5
replace tgyr0=`var' if tgyr==`var' | tgyr==`y'
}
tab tgyr0, m

collapse (sum)fdtna, by(quarter tgyr0)
*** move from million to billion
replace fdtna=fdtna/1000

bys quarter: egen totaltna=sum(fdtna)
ren fdtna tna
reshape wide tna, i(quarter totaltna) j(tgyr0)

replace tna2000=0 if tna2000==.

gen tmp=tna2000
foreach var in 2010 2020 2030 2040 2050 2060 {
replace tna`var'=0 if tna`var'==.
replace tmp=tmp+tna`var'
}
corr totaltna tmp
drop tmp
*** reduce to yearly
gen qt=quarter(dofq(quarter))
gen year=year(dofq(quarter))
keep if qt==4
drop quarter qt

foreach i in 2010 2020 2030 2040 2050 2060 {
	label var tna`i' "`i'"
}

line tna2010 tna2020 tna2030 tna2040 tna2050 tna2060 year, title("") xlab(2000(4)2022) xtitle("Year") ytitle("$ Billion") legend(title("Target retirement year", size(normal)) row(2) position(6)) graphregion(color(white)) bgcolor(white) scheme(s2color)
gr export "../Writing/TDF_by_tgyr_2022.png", replace

*****************************************
**** Plot hybrid fund share in 401k using ICI data
import delimited "../Data/DOL/ICI_401k_shares.csv", clear varnames(1)
split date, parse(":")
destring date1, replace
replace date2=subinstr(date2,"Q","",.)
destring date2, replace
replace date2=4 if date2==.
gen quarter=yq(date1,date2)
order quarter
format quarter %tq
drop date date1 
foreach var of varlist domeq_assets-total_assets {
    replace `var'=subinstr(`var',"$","",.)
	replace `var'=subinstr(`var',"%","",.)
	replace `var'=subinstr(`var',",","",.)
	destring `var', replace
}
foreach var in domeq_share foreq_share hybrid_share bond_share mm_share {
    replace `var'=`var'/100
}
drop if quarter==.

line domeq_share quarter
line foreq_share quarter
line bond_share quarter
line mm_share quarter

keep if date2==4
gen year=yofd(dofq(quarter))

line hybrid_share year, xline(2005) text(0.3 2005 "Pension Protection Act of 2006", place(e) color(maroon)) graphregion(color(white)) bgcolor(white) ytitle("Fraction") xtitle("Year") note("Source: ICI Retirement Market Data, plotted by authors")
gr export "../Writing/401k_inhybrid.png", replace
